"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _Image = require("./Image");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<Image />', function () {
  var source = _faker["default"].image.imageUrl();

  describe('sources', function () {
    it('renders a picture element with sources with an img fallback', function () {
      var description = _faker["default"].random.words();

      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: [{
          source: source
        }],
        description: description,
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('picture');
      expect(image).toContainReactComponent('source', {
        srcSet: source
      });
      expect(image).toContainReactComponent('img', {
        src: source,
        alt: description,
        loading: 'lazy'
      });
    });
    it('reduces multiple sources with the same viewportSize into a single srcSet', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: [{
          source: source,
          viewportSize: 'small',
          resolution: 1
        }, {
          source: source,
          viewportSize: 'small',
          resolution: 2
        }],
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('source', {
        srcSet: "".concat(source, " 1x, ").concat(source, " 2x"),
        media: _Image.MEDIA_MAP.get('small')
      });
    });
    it('renders an img element only when no sources are provided', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('picture');
      expect(image).not.toContainReactComponent('source');
      expect(image).toContainReactComponent('img', {
        src: source
      });
    });
  });
  describe('decorative', function () {
    it('wraps the image with <HiddenForAccessibility />', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        decorative: true
      }));
      expect(image).toContainReactComponent(_HiddenForAccessibility.HiddenForAccessibility);
    });
    it('by default the image is not wrapped with <HiddenForAccessibility />', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent(_HiddenForAccessibility.HiddenForAccessibility);
    });
  });
  describe('aspectRatio', function () {
    it('wraps the image with placeholder container', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        aspectRatio: 16 / 9
      }));
      expect(image).toContainReactComponent('div', {
        style: {
          paddingBottom: "calc(100% / ".concat(16 / 9, ")")
        }
      });
    });
    it('by default the image does not have any container', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('div');
    });
  });
});