"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.roundOffsets = roundOffsets;
exports.computeOffsets = computeOffsets;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var SPACING = 10; // Round the offsets to the nearest suitable subpixel
// based on the device pixel ratio.

function roundOffsets(_ref) {
  var x = _ref.x,
      y = _ref.y;
  var dpr = window.devicePixelRatio || 1;
  return {
    x: Math.round(x * dpr) / dpr || 0,
    y: Math.round(y * dpr) / dpr || 0
  };
}

function computeOffsets(placement, popperRect, referenceRect) {
  var _ref2 = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {},
      _ref2$offset = _ref2.offset,
      offset = _ref2$offset === void 0 ? 0 : _ref2$offset,
      _ref2$preventOverflow = _ref2.preventOverflow,
      preventOverflow = _ref2$preventOverflow === void 0 ? false : _ref2$preventOverflow,
      _ref2$sameInlineSize = _ref2.sameInlineSize,
      sameInlineSize = _ref2$sameInlineSize === void 0 ? false : _ref2$sameInlineSize;

  var offsets = {
    x: 0,
    y: 0
  };
  var clipping = {
    left: 0,
    right: 0
  };
  var spacing = 0;

  if (!popperRect || !referenceRect) {
    return {
      offsets: offsets,
      clipping: clipping,
      spacing: spacing
    };
  }

  var commonX = sameInlineSize ? referenceRect.left : referenceRect.left + referenceRect.width / 2 - popperRect.width / 2;
  var commonY = referenceRect.top + referenceRect.height / 2 - popperRect.height / 2;

  switch (placement) {
    case 'blockStart':
      offsets = {
        x: commonX,
        y: referenceRect.top - popperRect.height - offset
      };
      break;

    case 'blockEnd':
      offsets = {
        x: commonX,
        y: referenceRect.bottom + offset
      };
      break;

    case 'inlineStart':
      offsets = {
        x: referenceRect.left - popperRect.width - offset,
        y: commonY
      };
      break;

    case 'inlineEnd':
      offsets = {
        x: referenceRect.right + offset,
        y: commonY
      };
      break;
  }

  if (preventOverflow) {
    clipping = getClipping(offsets, popperRect);

    if (clipping.right && !clipping.left) {
      offsets.x += clipping.right;
      spacing = -SPACING;
    }

    if (!clipping.right && clipping.left) {
      offsets.x = 0;
      spacing = SPACING;
    }
  }

  return {
    offsets: offsets,
    clipping: clipping,
    spacing: spacing
  };
}

function getClipping(offsets, popperRect) {
  var viewportWidth = document.documentElement.clientWidth;
  var elementWidth = offsets.x + popperRect.width;
  var clipping = {
    left: 0,
    right: 0
  };

  if (elementWidth > viewportWidth) {
    clipping = _objectSpread(_objectSpread({}, clipping), {}, {
      right: viewportWidth - elementWidth
    });
  }

  if (offsets.x < 0) {
    clipping = _objectSpread(_objectSpread({}, clipping), {}, {
      left: -offsets.x
    });
  }

  return clipping;
}