"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Link = require("../Link");

var _TextBlock = require("../TextBlock");

var _Heading = require("../Heading");

var _VisuallyHidden = require("../VisuallyHidden");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _ReviewItem = require("./ReviewItem");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  label: 'Contact',
  children: 'snowdevil@shopify.com'
};
describe('<ReviewItem />', function () {
  describe('label', function () {
    it('renders the label', function () {
      var label = 'Ship to';
      var reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
        label: label
      })));
      expect(reviewItem).toContainReactText(label);
    });
  });
  describe('children', function () {
    it('does not render a link when not provided', function () {
      var content = 'snowdevil@shopify.com';
      var reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, defaultProps, content));
      expect(reviewItem).toContainReactText(content);
    });
  });
  it('does not render a link when `to` is not provided', function () {
    var reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, {
      label: "Content"
    }, "snowdevil@shopify.com"));
    expect(reviewItem).not.toContainReactComponent(_Link.Link);
  });
  it('renders a link when `to` is provided', function () {
    var to = '/payment';
    var reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      to: to
    })));
    expect(reviewItem).toContainReactComponent(_Link.Link, {
      to: to
    });
  });
  it('renders a hidden label for screen readers when `linkAriaLabel` is provided', function () {
    var reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      to: "/information",
      linkLabel: "Change",
      linkAriaLabel: "Change contact information"
    })));
    expect(reviewItem.find(_Link.Link)).toContainReactComponent(_VisuallyHidden.VisuallyHidden, {
      children: 'Change contact information'
    });
    expect(reviewItem.find(_Link.Link)).toContainReactComponent(_HiddenForAccessibility.HiddenForAccessibility, {
      children: 'Change'
    });
  });
});
describe('<ReviewBlock />', function () {
  it('renders the children', function () {
    var reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewBlock, null, /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      label: "Ship to"
    }))));
    expect(reviewBlock).toContainReactComponent(_ReviewItem.ReviewItem);
  });
  it('renders a <Heading /> when a title is passed as a prop', function () {
    var reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewBlock, {
      title: "Review"
    }));
    var heading = reviewBlock.find(_Heading.Heading);
    expect(heading).toContainReactText('Review');
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': heading === null || heading === void 0 ? void 0 : heading.prop('id')
    });
  });
  it('renders a <VisuallyHidden> when a title and titleHidden are passed as props', function () {
    var _visuallyHidden$find;

    var reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_ReviewItem.ReviewBlock, {
      title: "Review",
      titleHidden: true
    }));
    var visuallyHidden = reviewBlock.find(_VisuallyHidden.VisuallyHidden);
    expect(visuallyHidden).toContainReactComponent(_TextBlock.TextBlock, {
      children: 'Review'
    });
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': visuallyHidden === null || visuallyHidden === void 0 ? void 0 : (_visuallyHidden$find = visuallyHidden.find(_TextBlock.TextBlock)) === null || _visuallyHidden$find === void 0 ? void 0 : _visuallyHidden$find.prop('id')
    });
  });
});