"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Select = Select;
exports.PLACEHOLDER_VALUE = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _InlineError = require("../InlineError");

var _Text = require("../Text");

var _Icon = require("../Icon");

var _Truncate = require("../Truncate");

var _BlockStack = require("../BlockStack");

var _InlineStack = require("../InlineStack");

var _Theme = require("../Theme");

var _autocomplete = require("../../utilities/autocomplete");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Select = _interopRequireDefault(require("./Select.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var PLACEHOLDER_VALUE = '';
exports.PLACEHOLDER_VALUE = PLACEHOLDER_VALUE;
var createId = (0, _id.createIdCreator)('Select');

function Select(_ref) {
  var explicitId = _ref.id,
      name = _ref.name,
      label = _ref.label,
      labelPosition = _ref.labelPosition,
      options = _ref.options,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? PLACEHOLDER_VALUE : _ref$value,
      disabled = _ref.disabled,
      readonly = _ref.readonly,
      required = _ref.required,
      error = _ref.error,
      autocomplete = _ref.autocomplete,
      placeholder = _ref.placeholder,
      _onChange = _ref.onChange,
      border = _ref.border,
      background = _ref.background,
      disclosureIconSeparator = _ref.disclosureIconSeparator;

  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.select,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.labelPosition,
      themeLabelPosition = _useThemeConfiguratio3 === void 0 ? 'inside' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.background,
      themeBackground = _useThemeConfiguratio4 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio4,
      _useThemeConfiguratio5 = _useThemeConfiguratio2.border,
      themeBorder = _useThemeConfiguratio5 === void 0 ? 'full' : _useThemeConfiguratio5,
      _useThemeConfiguratio6 = _useThemeConfiguratio2.borderColor,
      borderColor = _useThemeConfiguratio6 === void 0 ? 'base' : _useThemeConfiguratio6,
      _useThemeConfiguratio7 = _useThemeConfiguratio2.focusBorder,
      focusBorder = _useThemeConfiguratio7 === void 0 ? 'full' : _useThemeConfiguratio7,
      _useThemeConfiguratio8 = _useThemeConfiguratio2.disclosureIcon,
      disclosureIcon = _useThemeConfiguratio8 === void 0 ? 'caretDown' : _useThemeConfiguratio8,
      _useThemeConfiguratio9 = _useThemeConfiguratio2.disclosureIconSeparator,
      themeDisclosureIconSeparator = _useThemeConfiguratio9 === void 0 ? true : _useThemeConfiguratio9,
      typographyStyle = _useThemeConfiguratio2.typographyStyle,
      errorIndentation = _useThemeConfiguratio2.errorIndentation,
      errorTypographyStyle = _useThemeConfiguratio2.errorTypographyStyle,
      labelTypographyStyle = _useThemeConfiguratio.label.typographyStyle;

  var finalLabelPosition = labelPosition !== null && labelPosition !== void 0 ? labelPosition : themeLabelPosition;
  var finalBorder = border !== null && border !== void 0 ? border : themeBorder;
  var finalDisclosureIconSeparator = disclosureIconSeparator !== null && disclosureIconSeparator !== void 0 ? disclosureIconSeparator : themeDisclosureIconSeparator;
  var finalBackground = background !== null && background !== void 0 ? background : themeBackground;
  var id = (0, _id.useId)(explicitId, createId);

  var errorMarkup = error && /*#__PURE__*/_react["default"].createElement("span", {
    className: (errorIndentation && _Select["default"][(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles["default"][errorTypographyStyle])
  }, /*#__PURE__*/_react["default"].createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  var className = (0, _cssUtilities.classNames)(_Select["default"].Select, Boolean(error) && _Select["default"].hasError, disabled && _Select["default"]['Select-isDisabled'], readonly && _Select["default"]['Select-isReadOnly'], _Select["default"][(0, _cssUtilities.variationName)('Select-label', finalLabelPosition)], _Select["default"][(0, _cssUtilities.variationName)('Select-background', finalBackground)], _Select["default"][(0, _cssUtilities.variationName)('Select-border', finalBorder)], _Select["default"][(0, _cssUtilities.variationName)('Select-borderColor', borderColor)], _Select["default"][(0, _cssUtilities.variationName)('Select-focusBorder', focusBorder)], typographyStyle && _typographyStyles["default"][typographyStyle]);

  var labelMarkup = /*#__PURE__*/_react["default"].createElement("label", {
    className: (0, _cssUtilities.classNames)(_Select["default"].Label, _Select["default"][(0, _cssUtilities.variationName)('Label-position', finalLabelPosition)], _defineProperty({}, _Select["default"]['Label-isPlaceholder'], value === PLACEHOLDER_VALUE && placeholder === label), background && _Select["default"][(0, _cssUtilities.variationName)('Label-onBackground', background)]),
    htmlFor: id
  }, /*#__PURE__*/_react["default"].createElement(_Text.Text, {
    size: !(value === PLACEHOLDER_VALUE && placeholder === label) || finalLabelPosition === 'inside' ? 'small' : undefined,
    subdued: true,
    style: labelTypographyStyle
  }, /*#__PURE__*/_react["default"].createElement(_Truncate.Truncate, null, label)));

  var view = /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, finalLabelPosition === 'outside' || finalLabelPosition === 'inline' ? labelMarkup : null, /*#__PURE__*/_react["default"].createElement("div", {
    className: _Select["default"].Wrapper
  }, finalLabelPosition === 'inside' && labelMarkup, /*#__PURE__*/_react["default"].createElement("select", {
    name: name,
    id: id,
    disabled: disabled,
    onChange: function onChange(event) {
      return _onChange === null || _onChange === void 0 ? void 0 : _onChange(event.target.value);
    },
    required: required,
    value: value,
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": Boolean(error),
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete)
  }, placeholder && (value === PLACEHOLDER_VALUE || placeholder !== label) && /*#__PURE__*/_react["default"].createElement("option", {
    value: PLACEHOLDER_VALUE,
    hidden: placeholder === label,
    disabled: true
  }, placeholder === label ? /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, "\xA0") : placeholder), options.map(function (option) {
    return /*#__PURE__*/_react["default"].createElement("option", {
      key: option.value,
      value: option.value,
      disabled: option.disabled || readonly
    }, option.label);
  })), /*#__PURE__*/_react["default"].createElement("div", {
    className: (0, _cssUtilities.classNames)(_Select["default"].Selector, finalDisclosureIconSeparator && _Select["default"]['Selector-separated'], finalDisclosureIconSeparator && _Select["default"][(0, _cssUtilities.variationName)('Selector-borderColor', borderColor)])
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    source: disclosureIcon,
    size: "small"
  }))));

  return /*#__PURE__*/_react["default"].createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, finalLabelPosition === 'inline' ? /*#__PURE__*/_react["default"].createElement(_InlineStack.InlineStack, {
    spacing: "xtight",
    alignment: "center"
  }, view) : /*#__PURE__*/_react["default"].createElement(_View.View, null, view), errorMarkup);
}