"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Spinner = require("./Spinner");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<Spinner />', function () {
  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();
  });
  it('removes the Spinner styling when user prefers reduced motion and that accessible content is provided', function () {
    _jestDomMocks.matchMedia.setMedia(function () {
      return {
        matches: true
      };
    });

    var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null, "Loading"));
    expect(spinner).not.toContainReactComponent('div', {
      className: 'Spinner'
    });
  });
  describe('children', function () {
    it('renders the childrens if user prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: true
        };
      });

      var accessibleText = 'Loading';
      var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null, accessibleText));
      expect(spinner).toContainReactText(accessibleText);
    });
    it('does not renders the childrens if user does not prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });

      var accessibleText = 'Loading';
      var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null, accessibleText));
      expect(spinner).not.toContainReactText(accessibleText);
    });
    it('renders an Icon if childrens are not provided', function () {
      var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null));
      expect(spinner).toContainReactComponent(_Icon.Icon);
    });
  });
  describe('color', function () {
    it('renders an Icon with "accent" color by default', function () {
      var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null));
      expect(spinner).toContainReactComponent(_Icon.Icon, {
        appearance: 'accent'
      });
    });
    it('renders an Icon with with no color prop if "inherit" is passed', function () {
      var spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, {
        color: "inherit"
      }));
      expect(spinner).toContainReactComponent(_Icon.Icon, {
        appearance: undefined
      });
    });
  });
});