"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Button = require("../Button");

var _InlineError = require("../InlineError");

var _TextField = require("../TextField");

var _Stepper = require("./Stepper");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var defaultProps = {
  label: 'Quantity'
};
describe('<Stepper />', function () {
  it('renders a number input field with basic props', function () {
    var id = _faker["default"].random.alphaNumeric();

    var name = _faker["default"].random.word();

    var label = _faker["default"].random.word();

    var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, {
      id: id,
      name: name,
      label: label
    }));
    expect(stepper).toContainReactComponent(_TextField.Field, {
      id: id,
      name: name,
      label: label
    });
  });
  it('renders an error message when the error prop is provided', function () {
    var error = 'Limit reached';

    var id = _faker["default"].random.alphaNumeric();

    var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
      id: id,
      error: error
    })));
    expect(stepper).toContainReactComponent(_InlineError.InlineError, {
      controlID: id,
      children: error
    });
  });
  it('increases until it reaches the maximum', function () {
    var step = 2;
    var max = 1;
    var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
      step: step,
      max: max
    })));

    var _stepper$findAll = stepper.findAll(_Button.Button),
        _stepper$findAll2 = _slicedToArray(_stepper$findAll, 2),
        increaseButton = _stepper$findAll2[1];

    increaseButton.trigger('onPress');
    expect(stepper).toContainReactComponent(_TextField.Field, {
      value: "".concat(max)
    });
  });
  it('decreases until it reaches the minimum', function () {
    var step = 2;
    var min = 0;
    var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
      step: step,
      min: min
    })));

    var _stepper$findAll3 = stepper.findAll(_Button.Button),
        _stepper$findAll4 = _slicedToArray(_stepper$findAll3, 1),
        decreaseButton = _stepper$findAll4[0];

    decreaseButton.trigger('onPress');
    expect(stepper).toContainReactComponent(_TextField.Field, {
      value: "".concat(min)
    });
  });
  describe('onChange', function () {
    it('does not call onChange when the value changes but is not committed, but updates the value in the input', function () {
      var onChange = jest.fn();

      var value = _faker["default"].random.number();

      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value,
        onChange: onChange
      })));
      stepper.find('input').trigger('onInput', {
        currentTarget: {
          value: "".concat(value)
        }
      });
      expect(onChange).not.toHaveBeenCalled();
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value)
      });
    });
    it('does not call onChange when the value changes and is committed, but matches the current prop value', function () {
      var onChange = jest.fn();

      var value = _faker["default"].random.number();

      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value,
        onChange: onChange
      })));
      stepper.find('input').trigger('onInput', {
        currentTarget: {
          value: "".concat(value)
        }
      });
      expect(onChange).not.toHaveBeenCalled();
    });
    it('calls onChange when the value changes and is committed, and does not match the current prop value', function () {
      var onChange = jest.fn();
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: 0,
        onChange: onChange
      })));

      var value = _faker["default"].random.number();

      stepper.find('input').trigger('onInput', {
        currentTarget: {
          value: "".concat(value)
        }
      });
      stepper.find('input').trigger('onChange', {
        currentTarget: {
          value: "".concat(value)
        }
      });
      expect(onChange).toHaveBeenCalledWith("".concat(value));
    });
  });
  describe('max', function () {
    it('does not increase when value is at the maximum', function () {
      var value = 10;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value,
        max: 10
      })));

      var _stepper$findAll5 = stepper.findAll(_Button.Button),
          _stepper$findAll6 = _slicedToArray(_stepper$findAll5, 2),
          increaseButton = _stepper$findAll6[1];

      increaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value)
      });
    });
    describe('going to default maximum value when input is greater than maximum', function () {
      it('increase button is clicked', function () {
        var value = 200;
        var max = 10;
        var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
          value: value,
          max: max
        })));

        var _stepper$findAll7 = stepper.findAll(_Button.Button),
            _stepper$findAll8 = _slicedToArray(_stepper$findAll7, 2),
            increaseButton = _stepper$findAll8[1];

        increaseButton.trigger('onPress');
        expect(stepper).toContainReactComponent(_TextField.Field, {
          value: "".concat(max)
        });
      });
      it('decrease button is clicked', function () {
        var value = 200;
        var max = 10;
        var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
          value: value,
          max: max
        })));

        var _stepper$findAll9 = stepper.findAll(_Button.Button),
            _stepper$findAll10 = _slicedToArray(_stepper$findAll9, 1),
            decreaseButton = _stepper$findAll10[0];

        decreaseButton.trigger('onPress');
        expect(stepper).toContainReactComponent(_TextField.Field, {
          value: "".concat(max)
        });
      });
    });
  });
  describe('min', function () {
    it('does not decrease when value is at the minimum', function () {
      var min = 0;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        min: min
      })));

      var _stepper$findAll11 = stepper.findAll(_Button.Button),
          _stepper$findAll12 = _slicedToArray(_stepper$findAll11, 1),
          decreaseButton = _stepper$findAll12[0];

      decreaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(min)
      });
    });
    describe('going to default minimum value when input is less than minimum', function () {
      it('increase button is clicked', function () {
        var value = -100;
        var min = 1;
        var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
          value: value,
          min: min
        })));

        var _stepper$findAll13 = stepper.findAll(_Button.Button),
            _stepper$findAll14 = _slicedToArray(_stepper$findAll13, 2),
            increaseButton = _stepper$findAll14[1];

        increaseButton.trigger('onPress');
        expect(stepper).toContainReactComponent(_TextField.Field, {
          value: "".concat(min)
        });
      });
      it('decrease button is clicked', function () {
        var value = -100;
        var min = 1;
        var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
          value: value,
          min: min
        })));

        var _stepper$findAll15 = stepper.findAll(_Button.Button),
            _stepper$findAll16 = _slicedToArray(_stepper$findAll15, 1),
            decreaseButton = _stepper$findAll16[0];

        decreaseButton.trigger('onPress');
        expect(stepper).toContainReactComponent(_TextField.Field, {
          value: "".concat(min)
        });
      });
    });
  });
  describe('<Button/>', function () {
    it('increases when the increase button is clicked on', function () {
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, defaultProps));

      var _stepper$findAll17 = stepper.findAll(_Button.Button),
          _stepper$findAll18 = _slicedToArray(_stepper$findAll17, 2),
          increaseButton = _stepper$findAll18[1];

      increaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(1)
      });
    });
    it('decreases when the decrease button is clicked on', function () {
      var value = 2;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value
      })));

      var _stepper$findAll19 = stepper.findAll(_Button.Button),
          _stepper$findAll20 = _slicedToArray(_stepper$findAll19, 1),
          decreaseButton = _stepper$findAll20[0];

      decreaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value - 1)
      });
    });
  });
  describe('value', function () {
    it('decreases from the initial value', function () {
      var value = 1;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value
      })));

      var _stepper$findAll21 = stepper.findAll(_Button.Button),
          _stepper$findAll22 = _slicedToArray(_stepper$findAll21, 1),
          decreaseButton = _stepper$findAll22[0];

      decreaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value - 1)
      });
    });
    it('increases from the initial value', function () {
      var value = 1;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        value: value
      })));

      var _stepper$findAll23 = stepper.findAll(_Button.Button),
          _stepper$findAll24 = _slicedToArray(_stepper$findAll23, 2),
          increaseButton = _stepper$findAll24[1];

      increaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value + 1)
      });
    });
  });
  describe('step', function () {
    it('decrease based on the step value', function () {
      var value = 2;
      var step = 2;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        step: step,
        value: value
      })));

      var _stepper$findAll25 = stepper.findAll(_Button.Button),
          _stepper$findAll26 = _slicedToArray(_stepper$findAll25, 1),
          decreaseButton = _stepper$findAll26[0];

      decreaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(value - step)
      });
    });
    it('increases based on the step value', function () {
      var step = 2;
      var stepper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Stepper.Stepper, Object.assign({}, defaultProps, {
        step: step
      })));

      var _stepper$findAll27 = stepper.findAll(_Button.Button),
          _stepper$findAll28 = _slicedToArray(_stepper$findAll27, 2),
          increaseButton = _stepper$findAll28[1];

      increaseButton.trigger('onPress');
      expect(stepper).toContainReactComponent(_TextField.Field, {
        value: "".concat(step)
      });
    });
  });
});