function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useState } from 'react';
import { mountWithContext } from '../../test-utilities';
import { Field } from '../TextField';
import { Labelled } from '../Labelled';
import { Autocomplete, AutocompleteOptions, AutocompleteOption, AutocompleteFooter } from './Autocomplete';
jest.mock('../../utilities/focus', function () {
  return {
    isFocused: jest.fn()
  };
});

var _ref = jest.requireMock('../../utilities/focus'),
    isFocused = _ref.isFocused;

var defaultProps = {
  id: 'address',
  label: 'Address',
  name: 'address',
  options: ['address 1', 'address 2'],
  value: '',
  title: 'Suggestions',
  ariaLabel: 'Close Predictions'
};

var autocompleteOptions = function autocompleteOptions(options) {
  return /*#__PURE__*/React.createElement(AutocompleteOptions, null, options && options.map(function (option) {
    return /*#__PURE__*/React.createElement(AutocompleteOption, {
      key: option
    }, option);
  }));
};

describe('<Autocomplete />', function () {
  beforeEach(function () {
    isFocused.mockReset();
    isFocused.mockImplementation(function () {
      return true;
    });
  });
  describe('<Labelled />', function () {
    it('renders a <Labelled />', function () {
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(Labelled);
    });
  });
  describe('<Field />', function () {
    it('renders a <Field />', function () {
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(Field, {
        id: 'address'
      });
    });
    it('renders a disabled <Field /> when the disabled prop is true', function () {
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        disabled: true,
        options: []
      })));
      expect(autocomplete).toContainReactComponent(Field, {
        disabled: true
      });
    });
    it('renders a readonly <Field /> when the readonly prop is true', function () {
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        readonly: true,
        options: []
      })));
      expect(autocomplete).toContainReactComponent(Field, {
        readonly: true
      });
    });
    it('sets the default aria-controls and aria-expanded properties', function () {
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaExpanded: false
      });
    });
    it('sets the aria-controls, aria-activedescendant and aria-expanded when the input is focused', function () {
      var _autocomplete$find;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps));
      (_autocomplete$find = autocomplete.find(Field)) === null || _autocomplete$find === void 0 ? void 0 : _autocomplete$find.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaActiveDescendant: 'address-option-0',
        ariaExpanded: true
      });
    });
    it('calls the onChange callback when the Field onChange is called', function () {
      var _autocomplete$find2;

      var onChangeSpy = jest.fn();
      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      })));
      (_autocomplete$find2 = autocomplete.find(Field)) === null || _autocomplete$find2 === void 0 ? void 0 : _autocomplete$find2.trigger('onInput', 'address');
      expect(onChangeSpy.mock.calls).toMatchObject([['address']]);
      expect(onChangeSpy).toHaveBeenCalledTimes(1);
    });
  });
  describe('<AutocompleteOptions />', function () {
    it('renders when the input is focused', function () {
      var _autocomplete$find3;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find3 = autocomplete.find(Field)) === null || _autocomplete$find3 === void 0 ? void 0 : _autocomplete$find3.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(AutocompleteOptions, {
        children: expect.any(Array)
      });
    });
    it("doesn't render when no options", function () {
      var _autocomplete$find4;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
        options: []
      }), autocompleteOptions(defaultProps.options)));
      (_autocomplete$find4 = autocomplete.find(Field)) === null || _autocomplete$find4 === void 0 ? void 0 : _autocomplete$find4.trigger('onFocus');
      expect(autocomplete).not.toContainReactComponent(AutocompleteOptions);
    });
    it('renders when the options change', function () {
      var _options$find;

      function Options() {
        var _useState = useState([]),
            _useState2 = _slicedToArray(_useState, 2),
            options = _useState2[0],
            setOptions = _useState2[1];

        var search = function search() {
          setOptions(['address 1', 'address 2']);
        };

        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Autocomplete, Object.assign({}, defaultProps, {
          options: options
        }), autocompleteOptions(defaultProps.options)), /*#__PURE__*/React.createElement("button", {
          onClick: search
        }));
      }

      var options = mountWithContext( /*#__PURE__*/React.createElement(Options, null));
      expect(options).not.toContainReactComponent(AutocompleteOptions);
      (_options$find = options.find('button')) === null || _options$find === void 0 ? void 0 : _options$find.trigger('onClick');
      expect(options).toContainReactComponent(AutocompleteOptions, {
        children: expect.any(Array)
      });
    });
    it("doesn't render when the value is empty", function () {
      var _autocomplete$find5;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find5 = autocomplete.find(Field)) === null || _autocomplete$find5 === void 0 ? void 0 : _autocomplete$find5.trigger('onInput', '');
      expect(autocomplete).not.toContainReactComponent(AutocompleteOptions);
    });
    it('renders an <ul> with unique id', function () {
      var _autocomplete$find6;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find6 = autocomplete.find(Field)) === null || _autocomplete$find6 === void 0 ? void 0 : _autocomplete$find6.trigger('onFocus');
      expect(autocomplete).toContainReactComponent('ul', {
        id: 'address-options'
      });
    });
    it('hides when the close button is clicked', function () {
      var _autocomplete$find7, _autocomplete$find8;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find7 = autocomplete.find(Field)) === null || _autocomplete$find7 === void 0 ? void 0 : _autocomplete$find7.trigger('onFocus');
      (_autocomplete$find8 = autocomplete.find('button')) === null || _autocomplete$find8 === void 0 ? void 0 : _autocomplete$find8.trigger('onClick');
      expect(autocomplete).not.toContainReactComponent(AutocompleteOptions);
    });
  });
  describe('<AutocompleteOption />', function () {
    it('selects the first option when focus is on field', function () {
      var _autocomplete$find9;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find9 = autocomplete.find(Field)) === null || _autocomplete$find9 === void 0 ? void 0 : _autocomplete$find9.trigger('onFocus');

      var _autocomplete$findAll = autocomplete.findAll(AutocompleteOption),
          _autocomplete$findAll2 = _slicedToArray(_autocomplete$findAll, 2),
          firstOption = _autocomplete$findAll2[0],
          secondOption = _autocomplete$findAll2[1];

      expect(firstOption.prop('isSelected')).toStrictEqual(true);
      expect(secondOption.prop('isSelected')).toStrictEqual(false);
    });
    it('renders a <li> with unique id', function () {
      var _autocomplete$find10;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find10 = autocomplete.find(Field)) === null || _autocomplete$find10 === void 0 ? void 0 : _autocomplete$find10.trigger('onFocus');

      var _autocomplete$findAll3 = autocomplete.findAll(AutocompleteOption),
          _autocomplete$findAll4 = _slicedToArray(_autocomplete$findAll3, 2),
          firstOption = _autocomplete$findAll4[0],
          secondOption = _autocomplete$findAll4[1];

      expect(firstOption).toContainReactComponent('li', {
        id: 'address-option-0'
      });
      expect(secondOption).toContainReactComponent('li', {
        id: 'address-option-1'
      });
    });
  });
  describe('<AutocompleteFooter />', function () {
    it('renders when the input is focused', function () {
      var _autocomplete$find11;

      var autocomplete = mountWithContext( /*#__PURE__*/React.createElement(Autocomplete, defaultProps, /*#__PURE__*/React.createElement(AutocompleteFooter, null, "This is a test footer"), ";"));
      (_autocomplete$find11 = autocomplete.find(Field)) === null || _autocomplete$find11 === void 0 ? void 0 : _autocomplete$find11.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(AutocompleteFooter, {
        children: 'This is a test footer'
      });
    });
  });
});