import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Text } from '../Text';
import { Bookend } from '../Bookend';
import { Banner } from './Banner';
var defaultProps = {
  title: 'There was an error'
};
describe('<Banner />', function () {
  describe('children', function () {
    it('renders the children', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps, /*#__PURE__*/React.createElement(Text, null, "Hello")));
      expect(banner).toContainReactComponent(Text);
      expect(banner).toContainReactComponent(Bookend, {
        trailing: false
      });
    });
  });
  describe('title', function () {
    it('renders the title', function () {
      var title = 'There was an error.';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, {
        title: title
      }));
      expect(banner).toContainReactText(title);
    });
  });
  describe('status', function () {
    it('renders the info <Icon /> by default', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps));
      expect(banner).toContainReactComponent(Icon, {
        source: 'info'
      });
    });
    it('renders the success <Icon /> if status is success', function () {
      var status = 'success';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(Icon, {
        source: status
      });
    });
    it('renders the warning <Icon /> if status is warning', function () {
      var status = 'warning';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(Icon, {
        source: status
      });
    });
    it('renders the critical <Icon /> if status is critical', function () {
      var status = 'critical';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(Icon, {
        source: status
      });
    });
    it('sets the status live region role by default', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps));
      expect(banner).toContainReactComponent('div', {
        role: 'status'
      });
    });
    it('sets the alert live region role if status is critical', function () {
      var status = 'critical';
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent('div', {
        role: 'alert'
      });
    });
  });
  describe('collapsible', function () {
    it('renders a chevronDown button with the required aria attributes if collapsible', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent('button', {
        'aria-pressed': false,
        'aria-expanded': false
      });
      expect(banner).toContainReactComponent(Icon, {
        source: 'chevronDown'
      });
      expect(banner).toContainReactComponent(Bookend, {
        trailing: true
      });
    });
    it('hides the children if collapsible', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/React.createElement(Text, null, "Hello")));
      expect(banner).not.toContainReactComponent(Text);
    });
    it('renders a chevronUp button with the required aria attributes icon on button click if collapsible', function () {
      var _banner$find;

      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      (_banner$find = banner.find('button')) === null || _banner$find === void 0 ? void 0 : _banner$find.trigger('onClick');
      expect(banner).toContainReactComponent('button', {
        'aria-pressed': true,
        'aria-expanded': true
      });
      expect(banner).toContainReactComponent(Icon, {
        source: 'chevronUp'
      });
      expect(banner).toContainReactComponent(Bookend, {
        trailing: true
      });
    });
    it('renders the children on button click if collapsible', function () {
      var _banner$find2;

      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/React.createElement(Text, null, "Hello")));
      (_banner$find2 = banner.find('button')) === null || _banner$find2 === void 0 ? void 0 : _banner$find2.trigger('onClick');
      expect(banner).toContainReactComponent(Text);
    });
  });
  describe('iconHidden', function () {
    it('renders the <Icon /> by default', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps));
      expect(banner).toContainReactComponent(Icon);
      expect(banner).toContainReactComponent(Bookend, {
        leading: true
      });
    });
    it('does not render the <Icon /> if iconHidden', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        iconHidden: true
      })));
      expect(banner).not.toContainReactComponent(Icon);
      expect(banner).toContainReactComponent(Bookend, {
        leading: false
      });
    });
  });
  describe('autofocus', function () {
    var rawCreateElement = document.createElement;
    var focusSpy = jest.fn();
    var createElementSpy = jest.spyOn(document, 'createElement');
    beforeEach(function () {
      createElementSpy.mockImplementation(function () {
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        var result = rawCreateElement.apply(document, args);

        if (args[0].toLocaleLowerCase() === 'div') {
          result.focus = focusSpy;
        }

        return result;
      });
    });
    afterEach(function () {
      focusSpy.mockReset();
    });
    afterAll(function () {
      createElementSpy.mockRestore();
    });
    it('does not focus the banner by default', function () {
      mountWithContext( /*#__PURE__*/React.createElement(Banner, defaultProps));
      expect(focusSpy).not.toHaveBeenCalled();
    });
    it('focuses on the banner when autofocus is specified', function () {
      mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        autofocus: true
      })));
      expect(focusSpy).toHaveBeenCalledTimes(1);
    });
    it('sets the tabIndex to -1', function () {
      var banner = mountWithContext( /*#__PURE__*/React.createElement(Banner, Object.assign({}, defaultProps, {
        autofocus: true
      })));
      expect(banner).toContainReactComponent('div', {
        tabIndex: -1
      });
    });
  });
});