import React from 'react';
import { AutoHeadingGroup } from '@quilted/react-auto-headings';
import { mountWithContext } from '../../test-utilities';
import { Heading } from './Heading';
describe('<Heading />', function () {
  it('renders its children', function () {
    var text = 'Snowdevil';
    var heading = mountWithContext( /*#__PURE__*/React.createElement(Heading, null, text));
    expect(heading).toContainReactText(text);
  });
  it('uses a <p> when the role is set to presentation', function () {
    var heading = mountWithContext( /*#__PURE__*/React.createElement(Heading, {
      role: "presentation"
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p');
  });
  it('assigns an id and focusable tabIndex on the element when an id is set', function () {
    var id = 'MyId';
    var heading = mountWithContext( /*#__PURE__*/React.createElement(Heading, {
      role: "presentation",
      id: id
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p', {
      id: id,
      tabIndex: -1
    });
  });
  it('uses a heading based on the semantic heading level', function () {
    var headings = mountWithContext( /*#__PURE__*/React.createElement(AutoHeadingGroup, {
      level: 1
    }, /*#__PURE__*/React.createElement(Heading, {
      id: "one"
    }, "Snowdevil"), /*#__PURE__*/React.createElement(AutoHeadingGroup, null, /*#__PURE__*/React.createElement(Heading, {
      id: "two"
    }, "History"))));
    expect(headings).toContainReactComponent('h1', {
      id: 'one'
    });
    expect(headings).toContainReactComponent('h2', {
      id: 'two'
    });
  });
});