function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useReducer, useMemo, useCallback, useEffect } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { useMounted } from '../../utilities/mounted';
import { Text } from '../Text';
import { Truncate } from '../Truncate';
import { useThemeConfiguration } from '../Theme';
import { LabelledContext } from './context';
import styles from './Labelled.css';
export function Labelled(_ref) {
  var children = _ref.children,
      label = _ref.label,
      htmlFor = _ref.htmlFor,
      _ref$isEmpty = _ref.isEmpty,
      isEmpty = _ref$isEmpty === void 0 ? true : _ref$isEmpty,
      _ref$position = _ref.position,
      position = _ref$position === void 0 ? 'inside' : _ref$position,
      _ref$background = _ref.background,
      background = _ref$background === void 0 ? 'surfaceTertiary' : _ref$background,
      subdued = _ref.subdued;
  var mounted = useMounted();

  var _useReducer = useReducer(function (state, action) {
    if (!mounted.current) return state;

    switch (action.type) {
      case 'focus':
        {
          return _objectSpread(_objectSpread({}, state), {}, {
            isFocused: true
          });
        }

      case 'blur':
        {
          return _objectSpread(_objectSpread({}, state), {}, {
            isFloating: !state.isEmpty,
            isFocused: false
          });
        }

      case 'change':
        {
          return _objectSpread(_objectSpread({}, state), {}, {
            isFloating: true,
            isEmpty: action.isEmpty
          });
        }

      case 'init':
        {
          return _objectSpread(_objectSpread({}, state), {}, {
            isFloating: !action.isEmpty,
            isEmpty: action.isEmpty
          });
        }
    }
  }, {
    isEmpty: isEmpty,
    isFloating: !isEmpty,
    isFocused: false
  }),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatch = _useReducer2[1]; // Handle value changes that bypasses the on Change handler
  // ie. asynchronously setting the value for a children


  useEffect(function () {
    if (!state.isFocused && state.isEmpty !== isEmpty) {
      dispatch({
        type: 'init',
        isEmpty: isEmpty
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [isEmpty]);
  var onFocus = useCallback(function () {
    return dispatch({
      type: 'focus'
    });
  }, []);
  var onBlur = useCallback(function () {
    return dispatch({
      type: 'blur'
    });
  }, []);
  var onChange = useCallback(function (isEmpty) {
    return dispatch({
      type: 'change',
      isEmpty: isEmpty
    });
  }, []);
  var value = useMemo(function () {
    return _objectSpread(_objectSpread({}, state), {}, {
      onBlur: onBlur,
      onChange: onChange,
      onFocus: onFocus
    });
  }, [onBlur, onChange, onFocus, state]);

  var _useThemeConfiguratio = useThemeConfiguration(),
      typographyStyle = _useThemeConfiguratio.label.typographyStyle;

  return /*#__PURE__*/React.createElement(LabelledContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames(_defineProperty({}, styles.isFloating, state.isFloating && position === 'inside'))
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: htmlFor,
    className: classNames(styles.Label, styles[variationName('Label-position', position)], subdued && styles['Label-isSubdued'], background && styles[variationName('Label-onBackground', background)])
  }, /*#__PURE__*/React.createElement(Text, {
    size: "small",
    subdued: true,
    style: typographyStyle
  }, /*#__PURE__*/React.createElement(Truncate, null, label))), children)));
}