import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { Portal } from '../Portal';
import { Modal } from './Modal';
describe('<Modal />', function () {
  var defaultIFrameSrc = faker.internet.url();
  describe('open prop', function () {
    it('renders the modal when the open prop is true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var modal;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                open: true,
                src: defaultIFrameSrc
              }));

            case 2:
              modal = _context.sent;
              expect(modal).toContainReactComponent(Portal);

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it("doesn't render the modal when the open prop is undefined", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      var modal;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc
              }));

            case 2:
              modal = _context2.sent;
              expect(modal).not.toContainReactComponent(Portal);

            case 4:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    it('calls onClose when open changes from true to false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      var onCloseSpy, modal;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context3.next = 3;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                onClose: onCloseSpy,
                src: defaultIFrameSrc,
                open: true
              }));

            case 3:
              modal = _context3.sent;
              modal.setProps({
                open: false
              });
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 6:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
  });
  it('renders an iframe is the src prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var iFrameSrc, iFrameName, modal;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            iFrameSrc = faker.internet.url();
            iFrameName = faker.random.words(2);
            _context4.next = 4;
            return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
              src: iFrameSrc,
              iFrameName: iFrameName,
              open: true
            }));

          case 4:
            modal = _context4.sent;
            expect(modal).toContainReactComponent('iframe', {
              src: iFrameSrc,
              name: iFrameName
            });

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('renders its children if no src prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var content, modal;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            content = faker.random.words(2);
            _context5.next = 3;
            return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
              open: true
            }, /*#__PURE__*/React.createElement("p", null, content)));

          case 3:
            modal = _context5.sent;
            expect(modal).not.toContainReactComponent('iframe');
            expect(modal).toContainReactText(content);

          case 6:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('renders a header if the title prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var title, modal;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            title = faker.random.words(2);
            _context6.next = 3;
            return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
              src: defaultIFrameSrc,
              title: title,
              open: true
            }));

          case 3:
            modal = _context6.sent;
            expect(modal).toContainReactComponent('header');
            expect(modal).toContainReactText(title);

          case 6:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  describe('when the escape key is pressed', function () {
    it('closes the modal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
      var modal, event;
      return _regeneratorRuntime.wrap(function _callee7$(_context7) {
        while (1) {
          switch (_context7.prev = _context7.next) {
            case 0:
              _context7.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                open: true
              }));

            case 2:
              modal = _context7.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(modal).not.toContainReactComponent(Portal);

            case 6:
            case "end":
              return _context7.stop();
          }
        }
      }, _callee7);
    })));
    it('calls onClose callback', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
      var onCloseSpy, modal, event;
      return _regeneratorRuntime.wrap(function _callee8$(_context8) {
        while (1) {
          switch (_context8.prev = _context8.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context8.next = 3;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                onClose: onCloseSpy,
                open: true
              }, "Hi"));

            case 3:
              modal = _context8.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 7:
            case "end":
              return _context8.stop();
          }
        }
      }, _callee8);
    })));
  });
  describe('when the close button is clicked', function () {
    it('closes the modal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
      var _modal$find;

      var modal;
      return _regeneratorRuntime.wrap(function _callee9$(_context9) {
        while (1) {
          switch (_context9.prev = _context9.next) {
            case 0:
              _context9.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                title: "A modal",
                open: true
              }));

            case 2:
              modal = _context9.sent;
              (_modal$find = modal.find('button')) === null || _modal$find === void 0 ? void 0 : _modal$find.trigger('onClick');
              expect(modal).not.toContainReactComponent(Portal);

            case 5:
            case "end":
              return _context9.stop();
          }
        }
      }, _callee9);
    })));
    it('calls onClose callback', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
      var _modal$find2;

      var onCloseSpy, modal;
      return _regeneratorRuntime.wrap(function _callee10$(_context10) {
        while (1) {
          switch (_context10.prev = _context10.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context10.next = 3;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                title: "A modal",
                onClose: onCloseSpy,
                open: true
              }, "Hi"));

            case 3:
              modal = _context10.sent;
              (_modal$find2 = modal.find('button')) === null || _modal$find2 === void 0 ? void 0 : _modal$find2.trigger('onClick');
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 6:
            case "end":
              return _context10.stop();
          }
        }
      }, _callee10);
    })));
  });
  describe('blocking prop', function () {
    it("doesn't render the close button", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
      var modal;
      return _regeneratorRuntime.wrap(function _callee11$(_context11) {
        while (1) {
          switch (_context11.prev = _context11.next) {
            case 0:
              _context11.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                title: "A modal",
                open: true,
                blocking: true
              }));

            case 2:
              modal = _context11.sent;
              expect(modal).not.toContainReactComponent('button');

            case 4:
            case "end":
              return _context11.stop();
          }
        }
      }, _callee11);
    })));
    it("doesn't close the modal when the escape key is pressed", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
      var modal, event;
      return _regeneratorRuntime.wrap(function _callee12$(_context12) {
        while (1) {
          switch (_context12.prev = _context12.next) {
            case 0:
              _context12.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                open: true,
                blocking: true
              }));

            case 2:
              modal = _context12.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(modal).toContainReactComponent(Portal);

            case 6:
            case "end":
              return _context12.stop();
          }
        }
      }, _callee12);
    })));
  });
  describe('long prop', function () {
    it("doesn't add the onLoad prop when present", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee13() {
      var modal, iframe;
      return _regeneratorRuntime.wrap(function _callee13$(_context13) {
        while (1) {
          switch (_context13.prev = _context13.next) {
            case 0:
              _context13.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                open: true,
                "long": true
              }));

            case 2:
              modal = _context13.sent;
              iframe = modal.find('iframe');
              expect(iframe === null || iframe === void 0 ? void 0 : iframe.prop('onLoad')).toBeUndefined();

            case 5:
            case "end":
              return _context13.stop();
          }
        }
      }, _callee13);
    })));
    it('adds the onLoad prop when absent', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee14() {
      var modal, iframe;
      return _regeneratorRuntime.wrap(function _callee14$(_context14) {
        while (1) {
          switch (_context14.prev = _context14.next) {
            case 0:
              _context14.next = 2;
              return mountWithContext( /*#__PURE__*/React.createElement(Modal, {
                src: defaultIFrameSrc,
                open: true
              }));

            case 2:
              modal = _context14.sent;
              iframe = modal.find('iframe');
              expect(iframe === null || iframe === void 0 ? void 0 : iframe.prop('onLoad')).not.toBeUndefined();

            case 5:
            case "end":
              return _context14.stop();
          }
        }
      }, _callee14);
    })));
  });
});