import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { VisuallyHidden } from '../VisuallyHidden';
import { OptionListContext } from './context';
import { OptionList } from './OptionList';
var defaultProps = {
  id: faker.random.uuid(),
  selectedItems: [faker.random.uuid()],
  onChange: function onChange() {
    return null;
  },
  children: /*#__PURE__*/React.createElement("div", null)
};
describe('<OptionList />', function () {
  it('renders its children', function () {
    function Children() {
      return /*#__PURE__*/React.createElement("div", null, "children");
    }

    var accordion = mountWithContext( /*#__PURE__*/React.createElement(OptionList, defaultProps, /*#__PURE__*/React.createElement(Children, null)));
    expect(accordion).toContainReactComponent(Children);
  });
  it('wraps children with OptionListContext', function () {
    var id = faker.random.uuid();
    var selectedItems = [faker.random.uuid()];

    var onChange = function onChange() {
      return null;
    };

    var allowMultiple = false;
    var accordion = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultProps, {
      id: id,
      selectedItems: selectedItems,
      onChange: onChange,
      allowMultiple: allowMultiple
    })));
    expect(accordion).toProvideReactContext(OptionListContext, {
      id: id,
      selectedItems: selectedItems,
      onChange: onChange,
      allowMultiple: allowMultiple
    });
  });
  it('renders a title if provided', function () {
    var title = faker.random.word();
    var accordion = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultProps, {
      title: title
    })));
    expect(accordion).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
  it('renders a hidden title if provided when titleHidden prop is set to true', function () {
    var title = faker.random.word();
    var accordion = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultProps, {
      title: title,
      titleHidden: true
    })));
    expect(accordion.find(VisuallyHidden)).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
});