import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { Link } from '../Link';
import { TextBlock } from '../TextBlock';
import { Heading } from '../Heading';
import { VisuallyHidden } from '../VisuallyHidden';
import { HiddenForAccessibility } from '../HiddenForAccessibility';
import { ReviewBlock, ReviewItem } from './ReviewItem';
var defaultProps = {
  label: 'Contact',
  children: 'snowdevil@shopify.com'
};
describe('<ReviewItem />', function () {
  describe('label', function () {
    it('renders the label', function () {
      var label = 'Ship to';
      var reviewItem = mountWithContext( /*#__PURE__*/React.createElement(ReviewItem, Object.assign({}, defaultProps, {
        label: label
      })));
      expect(reviewItem).toContainReactText(label);
    });
  });
  describe('children', function () {
    it('does not render a link when not provided', function () {
      var content = 'snowdevil@shopify.com';
      var reviewItem = mountWithContext( /*#__PURE__*/React.createElement(ReviewItem, defaultProps, content));
      expect(reviewItem).toContainReactText(content);
    });
  });
  it('does not render a link when `to` is not provided', function () {
    var reviewItem = mountWithContext( /*#__PURE__*/React.createElement(ReviewItem, {
      label: "Content"
    }, "snowdevil@shopify.com"));
    expect(reviewItem).not.toContainReactComponent(Link);
  });
  it('renders a link when `to` is provided', function () {
    var to = '/payment';
    var reviewItem = mountWithContext( /*#__PURE__*/React.createElement(ReviewItem, Object.assign({}, defaultProps, {
      to: to
    })));
    expect(reviewItem).toContainReactComponent(Link, {
      to: to
    });
  });
  it('renders a hidden label for screen readers when `linkAriaLabel` is provided', function () {
    var reviewItem = mountWithContext( /*#__PURE__*/React.createElement(ReviewItem, Object.assign({}, defaultProps, {
      to: "/information",
      linkLabel: "Change",
      linkAriaLabel: "Change contact information"
    })));
    expect(reviewItem.find(Link)).toContainReactComponent(VisuallyHidden, {
      children: 'Change contact information'
    });
    expect(reviewItem.find(Link)).toContainReactComponent(HiddenForAccessibility, {
      children: 'Change'
    });
  });
});
describe('<ReviewBlock />', function () {
  it('renders the children', function () {
    var reviewBlock = mountWithContext( /*#__PURE__*/React.createElement(ReviewBlock, null, /*#__PURE__*/React.createElement(ReviewItem, Object.assign({}, defaultProps, {
      label: "Ship to"
    }))));
    expect(reviewBlock).toContainReactComponent(ReviewItem);
  });
  it('renders a <Heading /> when a title is passed as a prop', function () {
    var reviewBlock = mountWithContext( /*#__PURE__*/React.createElement(ReviewBlock, {
      title: "Review"
    }));
    var heading = reviewBlock.find(Heading);
    expect(heading).toContainReactText('Review');
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': heading === null || heading === void 0 ? void 0 : heading.prop('id')
    });
  });
  it('renders a <VisuallyHidden> when a title and titleHidden are passed as props', function () {
    var _visuallyHidden$find;

    var reviewBlock = mountWithContext( /*#__PURE__*/React.createElement(ReviewBlock, {
      title: "Review",
      titleHidden: true
    }));
    var visuallyHidden = reviewBlock.find(VisuallyHidden);
    expect(visuallyHidden).toContainReactComponent(TextBlock, {
      children: 'Review'
    });
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': visuallyHidden === null || visuallyHidden === void 0 ? void 0 : (_visuallyHidden$find = visuallyHidden.find(TextBlock)) === null || _visuallyHidden$find === void 0 ? void 0 : _visuallyHidden$find.prop('id')
    });
  });
});