function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { View } from '../View';
import { InlineError } from '../InlineError';
import { Text } from '../Text';
import { Icon } from '../Icon';
import { Truncate } from '../Truncate';
import { BlockStack } from '../BlockStack';
import { InlineStack } from '../InlineStack';
import { useThemeConfiguration } from '../Theme';
import { autocompleteToHtml } from '../../utilities/autocomplete';
import { useId, createIdCreator } from '../../utilities/id';
import { errorId } from '../../utilities/errors';
import typographyStyles from '../../utilities/typography-styles.css';
import styles from './Select.css';
export var PLACEHOLDER_VALUE = '';
var createId = createIdCreator('Select');
export function Select(_ref) {
  var explicitId = _ref.id,
      name = _ref.name,
      label = _ref.label,
      labelPosition = _ref.labelPosition,
      options = _ref.options,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? PLACEHOLDER_VALUE : _ref$value,
      disabled = _ref.disabled,
      readonly = _ref.readonly,
      required = _ref.required,
      error = _ref.error,
      autocomplete = _ref.autocomplete,
      placeholder = _ref.placeholder,
      _onChange = _ref.onChange,
      border = _ref.border,
      background = _ref.background,
      disclosureIconSeparator = _ref.disclosureIconSeparator;

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.select,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.labelPosition,
      themeLabelPosition = _useThemeConfiguratio3 === void 0 ? 'inside' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.background,
      themeBackground = _useThemeConfiguratio4 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio4,
      _useThemeConfiguratio5 = _useThemeConfiguratio2.border,
      themeBorder = _useThemeConfiguratio5 === void 0 ? 'full' : _useThemeConfiguratio5,
      _useThemeConfiguratio6 = _useThemeConfiguratio2.borderColor,
      borderColor = _useThemeConfiguratio6 === void 0 ? 'base' : _useThemeConfiguratio6,
      _useThemeConfiguratio7 = _useThemeConfiguratio2.focusBorder,
      focusBorder = _useThemeConfiguratio7 === void 0 ? 'full' : _useThemeConfiguratio7,
      _useThemeConfiguratio8 = _useThemeConfiguratio2.disclosureIcon,
      disclosureIcon = _useThemeConfiguratio8 === void 0 ? 'caretDown' : _useThemeConfiguratio8,
      _useThemeConfiguratio9 = _useThemeConfiguratio2.disclosureIconSeparator,
      themeDisclosureIconSeparator = _useThemeConfiguratio9 === void 0 ? true : _useThemeConfiguratio9,
      typographyStyle = _useThemeConfiguratio2.typographyStyle,
      errorIndentation = _useThemeConfiguratio2.errorIndentation,
      errorTypographyStyle = _useThemeConfiguratio2.errorTypographyStyle,
      labelTypographyStyle = _useThemeConfiguratio.label.typographyStyle;

  var finalLabelPosition = labelPosition !== null && labelPosition !== void 0 ? labelPosition : themeLabelPosition;
  var finalBorder = border !== null && border !== void 0 ? border : themeBorder;
  var finalDisclosureIconSeparator = disclosureIconSeparator !== null && disclosureIconSeparator !== void 0 ? disclosureIconSeparator : themeDisclosureIconSeparator;
  var finalBackground = background !== null && background !== void 0 ? background : themeBackground;
  var id = useId(explicitId, createId);
  var errorMarkup = error && /*#__PURE__*/React.createElement("span", {
    className: (errorIndentation && styles[variationName('Error-errorIndentation', errorIndentation)], errorTypographyStyle && typographyStyles[errorTypographyStyle])
  }, /*#__PURE__*/React.createElement(InlineError, {
    controlID: id
  }, error));
  var className = classNames(styles.Select, Boolean(error) && styles.hasError, disabled && styles['Select-isDisabled'], readonly && styles['Select-isReadOnly'], styles[variationName('Select-label', finalLabelPosition)], styles[variationName('Select-background', finalBackground)], styles[variationName('Select-border', finalBorder)], styles[variationName('Select-borderColor', borderColor)], styles[variationName('Select-focusBorder', focusBorder)], typographyStyle && typographyStyles[typographyStyle]);
  var labelMarkup = /*#__PURE__*/React.createElement("label", {
    className: classNames(styles.Label, styles[variationName('Label-position', finalLabelPosition)], _defineProperty({}, styles['Label-isPlaceholder'], value === PLACEHOLDER_VALUE && placeholder === label), background && styles[variationName('Label-onBackground', background)]),
    htmlFor: id
  }, /*#__PURE__*/React.createElement(Text, {
    size: !(value === PLACEHOLDER_VALUE && placeholder === label) || finalLabelPosition === 'inside' ? 'small' : undefined,
    subdued: true,
    style: labelTypographyStyle
  }, /*#__PURE__*/React.createElement(Truncate, null, label)));
  var view = /*#__PURE__*/React.createElement(React.Fragment, null, finalLabelPosition === 'outside' || finalLabelPosition === 'inline' ? labelMarkup : null, /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, finalLabelPosition === 'inside' && labelMarkup, /*#__PURE__*/React.createElement("select", {
    name: name,
    id: id,
    disabled: disabled,
    onChange: function onChange(event) {
      return _onChange === null || _onChange === void 0 ? void 0 : _onChange(event.target.value);
    },
    required: required,
    value: value,
    className: className,
    "aria-describedby": error ? errorId(id) : undefined,
    "aria-invalid": Boolean(error),
    autoComplete: autocompleteToHtml(autocomplete)
  }, placeholder && (value === PLACEHOLDER_VALUE || placeholder !== label) && /*#__PURE__*/React.createElement("option", {
    value: PLACEHOLDER_VALUE,
    hidden: placeholder === label,
    disabled: true
  }, placeholder === label ? /*#__PURE__*/React.createElement(React.Fragment, null, "\xA0") : placeholder), options.map(function (option) {
    return /*#__PURE__*/React.createElement("option", {
      key: option.value,
      value: option.value,
      disabled: option.disabled || readonly
    }, option.label);
  })), /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.Selector, finalDisclosureIconSeparator && styles['Selector-separated'], finalDisclosureIconSeparator && styles[variationName('Selector-borderColor', borderColor)])
  }, /*#__PURE__*/React.createElement(Icon, {
    source: disclosureIcon,
    size: "small"
  }))));
  return /*#__PURE__*/React.createElement(BlockStack, {
    spacing: "tight"
  }, finalLabelPosition === 'inline' ? /*#__PURE__*/React.createElement(InlineStack, {
    spacing: "xtight",
    alignment: "center"
  }, view) : /*#__PURE__*/React.createElement(View, null, view), errorMarkup);
}