import React from 'react';
import { matchMedia } from '@shopify/jest-dom-mocks';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Spinner } from './Spinner';
describe('<Spinner />', function () {
  beforeEach(function () {
    matchMedia.mock();
  });
  afterEach(function () {
    matchMedia.restore();
  });
  it('removes the Spinner styling when user prefers reduced motion and that accessible content is provided', function () {
    matchMedia.setMedia(function () {
      return {
        matches: true
      };
    });
    var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, null, "Loading"));
    expect(spinner).not.toContainReactComponent('div', {
      className: 'Spinner'
    });
  });
  describe('children', function () {
    it('renders the childrens if user prefers reduced motion', function () {
      matchMedia.setMedia(function () {
        return {
          matches: true
        };
      });
      var accessibleText = 'Loading';
      var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, null, accessibleText));
      expect(spinner).toContainReactText(accessibleText);
    });
    it('does not renders the childrens if user does not prefers reduced motion', function () {
      matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });
      var accessibleText = 'Loading';
      var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, null, accessibleText));
      expect(spinner).not.toContainReactText(accessibleText);
    });
    it('renders an Icon if childrens are not provided', function () {
      var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, null));
      expect(spinner).toContainReactComponent(Icon);
    });
  });
  describe('color', function () {
    it('renders an Icon with "accent" color by default', function () {
      var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, null));
      expect(spinner).toContainReactComponent(Icon, {
        appearance: 'accent'
      });
    });
    it('renders an Icon with with no color prop if "inherit" is passed', function () {
      var spinner = mountWithContext( /*#__PURE__*/React.createElement(Spinner, {
        color: "inherit"
      }));
      expect(spinner).toContainReactComponent(Icon, {
        appearance: undefined
      });
    });
  });
});