"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Autocomplete = Autocomplete;
exports.AutocompleteOptions = AutocompleteOptions;
exports.AutocompleteOption = AutocompleteOption;
exports.AutocompleteFooter = AutocompleteFooter;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _BlockStack = require("../BlockStack");

var _TextField = require("../TextField");

var _Labelled = require("../Labelled");

var _Theme = require("../Theme");

var _Popper = require("../Popper");

var _Icon = require("../Icon");

var _InlineError = require("../InlineError");

var _strings = require("../../utilities/strings");

var _focus = require("../../utilities/focus");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Autocomplete = _interopRequireDefault(require("./Autocomplete.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Autocomplete({
  error,
  id,
  label,
  name,
  onChange,
  options,
  onSelectOption,
  value,
  ariaLabel,
  title,
  children,
  required,
  autocomplete,
  disabled,
  readonly
}) {
  const [open, setOpen] = (0, _react.useState)(false);
  const [selected, setSelected] = (0, _react.useState)(0);
  const fieldRef = (0, _react.useRef)(null);
  const popperRef = (0, _react.useRef)(null);
  const closeButtonRef = (0, _react.useRef)(null);
  const {
    textFields: {
      labelPosition,
      background = 'surfaceTertiary',
      errorIndentation,
      errorTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(errorIndentation && _Autocomplete.default[(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles.default[errorTypographyStyle])
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  const handleOpen = () => {
    if (open) {
      return;
    }

    if (options.length === 0) {
      return;
    } // Prevents opening the autocomplete when the address field is filled
    // via browser autofill.


    if (fieldRef.current == null || !(0, _focus.isFocused)(fieldRef.current)) return;
    setOpen(true);
  };

  const handleClose = (0, _react.useCallback)(() => {
    if (!open) {
      return;
    }

    setOpen(false);
  }, [open]);

  const handleChange = newValue => {
    if (newValue === '') {
      handleClose();
    } else {
      handleOpen();
    }

    if (onChange) {
      onChange(newValue);
    }
  };

  const handleOptionMouseOver = index => {
    setSelected(index);
  };

  const handleOptionMouseDown = index => {
    handleClose();

    if (onSelectOption) {
      onSelectOption(options[index]);
    }
  };

  const changeSelectedOption = diff => {
    if (!open) {
      return;
    }

    setSelected(selected => {
      if (selected + diff >= options.length) {
        return 0;
      } else if (selected + diff < 0) {
        return options.length - 1;
      }

      return selected + diff;
    });
  };

  const handleKeyDown = event => {
    switch (event.key) {
      case 'ArrowDown':
      case 'Down':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(1);
        handleOpen();
        break;

      case 'ArrowUp':
      case 'Up':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(-1);
        handleOpen();
        break;

      case 'Enter':
        if (open) {
          // Prevent form validation
          event.preventDefault();
          handleClose();

          if (onSelectOption) {
            onSelectOption(options[selected]);
          }
        }

        break;

      case 'Escape':
      case 'Esc':
        if (open) {
          handleClose();
        }

        break;

      case 'Tab':
        if (event.shiftKey) {
          handleClose();
        } else if (closeButtonRef.current) {
          closeButtonRef.current.focus();
          event.preventDefault();
        }

        break;
    }
  };

  const autocompleteOptions = _react.default.Children.map(children, child => {
    if ( /*#__PURE__*/_react.default.isValidElement(child) && child.type === AutocompleteOptions) {
      return /*#__PURE__*/_react.default.cloneElement(child, {
        id: `${id}-options`
      }, _react.default.Children.toArray(child.props.children).map((child, index) => {
        if (typeof child === 'object' && 'type' in child && child.type === AutocompleteOption) {
          return /*#__PURE__*/_react.default.cloneElement(child, {
            id: `${id}-option-${index}`,
            isSelected: selected === index,
            onMouseDown: () => {
              var _fieldRef$current;

              handleOptionMouseDown(index);
              (_fieldRef$current = fieldRef.current) === null || _fieldRef$current === void 0 ? void 0 : _fieldRef$current.focus();
            },
            onMouseOver: () => handleOptionMouseOver(index)
          });
        }
      }));
    }
  });

  (0, _react.useEffect)(() => {
    const handleClickOutside = event => {
      var _fieldRef$current2, _popperRef$current;

      if (event.target instanceof Node && !((_fieldRef$current2 = fieldRef.current) === null || _fieldRef$current2 === void 0 ? void 0 : _fieldRef$current2.contains(event.target)) && !((_popperRef$current = popperRef.current) === null || _popperRef$current === void 0 ? void 0 : _popperRef$current.contains(event.target))) {
        handleClose();
      } else if (event.target !== fieldRef.current) {
        var _fieldRef$current3;

        (_fieldRef$current3 = fieldRef.current) === null || _fieldRef$current3 === void 0 ? void 0 : _fieldRef$current3.focus();
      }
    };

    document.addEventListener('click', handleClickOutside);
    return () => {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [handleClose]);
  (0, _react.useEffect)(() => {
    if (options.length === 0) {
      // Prevents the loss of focus
      if (open && fieldRef.current && !(0, _focus.isFocused)(fieldRef.current)) {
        fieldRef.current.focus();
      }
    } else if (!open && fieldRef.current && (0, _focus.isFocused)(fieldRef.current)) {
      handleOpen();
    }
  }, // eslint-disable-next-line react-hooks/exhaustive-deps
  [options.length]);

  const autocompleteFooter = _react.default.Children.map(children, child => {
    if ( /*#__PURE__*/_react.default.isValidElement(child) && child.type === AutocompleteFooter) {
      return child;
    }
  });

  const fieldFocused = Boolean(fieldRef.current && (0, _focus.isFocused)(fieldRef.current));
  const closeButtonFocused = Boolean(closeButtonRef.current && (0, _focus.isFocused)(closeButtonRef.current));
  const renderPopper = open && options.length > 0 && (fieldFocused || closeButtonFocused);
  const autocompleteClassName = (0, _cssUtilities.classNames)(_Autocomplete.default.Autocomplete, background && _Autocomplete.default[(0, _cssUtilities.variationName)('background', background)]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, {
    label: label,
    htmlFor: id,
    isEmpty: (0, _strings.isEmptyString)(value),
    position: labelPosition,
    background: background,
    subdued: readonly
  }, /*#__PURE__*/_react.default.createElement(_TextField.Field, {
    ariaActiveDescendant: open ? `${id}-option-${selected}` : undefined,
    ariaAutocomplete: "list",
    ariaControls: `${id}-options`,
    ariaExpanded: renderPopper,
    required: required,
    autocomplete: !open && autocomplete,
    error: error,
    id: id,
    label: label,
    name: name,
    onInput: handleChange,
    onFocus: handleOpen,
    onKeyDown: handleKeyDown,
    ref: fieldRef,
    role: "combobox",
    value: value,
    disabled: disabled,
    readonly: readonly
  })), errorMarkup), renderPopper && /*#__PURE__*/_react.default.createElement(_Popper.Popper, {
    activator: fieldRef.current,
    sameInlineSize: true,
    minInlineSize: 320,
    preventOverflow: true,
    placement: "blockEnd",
    offset: 7
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: autocompleteClassName,
    ref: popperRef
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Autocomplete.default.Header
  }, /*#__PURE__*/_react.default.createElement("h3", {
    className: _Autocomplete.default.Title
  }, title), /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Autocomplete.default.Close,
    onClick: () => {
      var _fieldRef$current4;

      handleClose();
      (_fieldRef$current4 = fieldRef.current) === null || _fieldRef$current4 === void 0 ? void 0 : _fieldRef$current4.focus();
    },
    onKeyDown: event => {
      if (event.key === 'Tab') {
        if (event.shiftKey) {
          var _fieldRef$current5;

          (_fieldRef$current5 = fieldRef.current) === null || _fieldRef$current5 === void 0 ? void 0 : _fieldRef$current5.focus();
          event.preventDefault();
        } else {
          var _fieldRef$current6;

          handleClose();
          (_fieldRef$current6 = fieldRef.current) === null || _fieldRef$current6 === void 0 ? void 0 : _fieldRef$current6.focus();
        }
      }
    },
    ref: closeButtonRef
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    size: "default",
    source: "close",
    appearance: "subdued",
    accessibilityLabel: ariaLabel
  }))), autocompleteOptions, autocompleteFooter)));
}

function AutocompleteOptions({
  children,
  id
}) {
  return /*#__PURE__*/_react.default.createElement("ul", {
    className: _Autocomplete.default.Options,
    id: id,
    onMouseDown: event => {
      // Prevent blur
      event.preventDefault();
    } // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
    ,
    role: "listbox"
  }, children);
}

function AutocompleteOption({
  children,
  id,
  isSelected,
  onMouseDown,
  onMouseOver
}) {
  return (
    /*#__PURE__*/
    // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
    _react.default.createElement("li", {
      "aria-selected": isSelected,
      className: (0, _cssUtilities.classNames)(_Autocomplete.default.Option, {
        [_Autocomplete.default.selected]: isSelected
      }),
      id: id,
      onMouseDown: onMouseDown,
      onMouseOver: onMouseOver // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
      ,
      role: "option"
    }, children)
  );
}

function AutocompleteFooter({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Autocomplete.default.Footer
  }, children);
}