"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Banner = Banner;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _id = require("../../utilities/id");

var _AppContext = require("../AppContext");

var _Heading = require("../Heading");

var _HeadingGroup = require("../HeadingGroup");

var _Bookend = require("../Bookend");

var _Icon = require("../Icon");

var _View = require("../View");

var _TextContainer = require("../TextContainer");

var _Banner = _interopRequireDefault(require("./Banner.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('Banner');

function Banner({
  children,
  collapsible = false,
  iconHidden = false,
  status = 'info',
  title,
  autofocus = false
}) {
  const translate = (0, _AppContext.useTranslate)();
  const [collapsed, setCollapsed] = (0, _react.useState)(true);
  const bannerRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    if (autofocus === true) {
      var _bannerRef$current;

      bannerRef === null || bannerRef === void 0 ? void 0 : (_bannerRef$current = bannerRef.current) === null || _bannerRef$current === void 0 ? void 0 : _bannerRef$current.focus();
    }
  }, [autofocus]);
  const className = (0, _cssUtilities.classNames)(_Banner.default.Banner, status && _Banner.default[(0, _cssUtilities.variationName)('status', status)]);
  const id = (0, _id.useId)(undefined, createId);
  const controlId = collapsed ? undefined : id;
  const showChildren = !collapsible || collapsible && !collapsed;
  return /*#__PURE__*/_react.default.createElement("div", Object.assign({
    className: className,
    role: status === 'critical' ? 'alert' : 'status',
    "aria-atomic": "true",
    "aria-live": "polite"
  }, autofocus && {
    tabIndex: -1
  }, {
    ref: bannerRef
  }), /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    leading: !iconHidden,
    trailing: collapsible
  }, !iconHidden && /*#__PURE__*/_react.default.createElement("div", {
    className: _Banner.default.Icon
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: status
  })), /*#__PURE__*/_react.default.createElement(_TextContainer.TextContainer, {
    spacing: "tight"
  }, title && /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
    level: 3
  }, title), children && showChildren && /*#__PURE__*/_react.default.createElement("div", {
    className: _Banner.default.Content,
    id: controlId
  }, /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement(_View.View, null, children)))), collapsible && /*#__PURE__*/_react.default.createElement(_View.View, null, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Banner.default.Button,
    onClick: () => setCollapsed(collapsed => !collapsed),
    "aria-pressed": !collapsed,
    "aria-expanded": !collapsed,
    "aria-controls": controlId
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    size: "small",
    source: collapsed ? 'chevronDown' : 'chevronUp',
    accessibilityLabel: translate('expand')
  })))));
}