"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactAutoHeadings = require("@quilted/react-auto-headings");

var _testUtilities = require("../../test-utilities");

var _Heading = require("./Heading");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Heading />', () => {
  it('renders its children', () => {
    const text = 'Snowdevil';
    const heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Heading.Heading, null, text));
    expect(heading).toContainReactText(text);
  });
  it('uses a <p> when the role is set to presentation', () => {
    const heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
      role: "presentation"
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p');
  });
  it('assigns an id and focusable tabIndex on the element when an id is set', () => {
    const id = 'MyId';
    const heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
      role: "presentation",
      id: id
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p', {
      id,
      tabIndex: -1
    });
  });
  it('uses a heading based on the semantic heading level', () => {
    const headings = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_reactAutoHeadings.AutoHeadingGroup, {
      level: 1
    }, /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
      id: "one"
    }, "Snowdevil"), /*#__PURE__*/_react.default.createElement(_reactAutoHeadings.AutoHeadingGroup, null, /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
      id: "two"
    }, "History"))));
    expect(headings).toContainReactComponent('h1', {
      id: 'one'
    });
    expect(headings).toContainReactComponent('h2', {
      id: 'two'
    });
  });
});