"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Modal = Modal;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _AppContext = require("../AppContext");

var _Portal = require("../Portal");

var _Heading = require("../Heading");

var _Icon = require("../Icon");

var _transition = require("../../utilities/transition");

var _focusTrap = require("../../utilities/focusTrap");

var _Modal = _interopRequireDefault(require("./Modal.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const DEFAULT_IFRAME_CONTENT_HEIGHT = 400;

function isIFrameProps(props) {
  return props.src !== undefined;
}

function Modal({
  blocking = false,
  long = false,
  onClose,
  open: openProp = false,
  title,
  ...props
}) {
  const translate = (0, _AppContext.useTranslate)();
  const [open, setOpen] = (0, _react.useState)(openProp);
  const [iframeHeight, setIframeHeight] = (0, _react.useState)();
  const titleBarRef = (0, _react.useRef)(null);
  const activatorRef = (0, _react.useRef)(null);
  const modalRef = (0, _focusTrap.useFocusTrap)();
  const transition = (0, _transition.useTransition)(open, {
    enter: 'fast'
  });

  const transitionClassName = _Modal.default[(0, _cssUtilities.variationName)('transition', transition)];

  const closeModal = (0, _react.useCallback)(() => {
    setOpen(false);
    if ((activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current) instanceof HTMLElement) activatorRef.current.focus();
    if (onClose) onClose();
  }, [onClose]);
  const handleKeyDown = (0, _react.useCallback)(event => {
    if ((event.key === 'Escape' || event.key === 'Esc') && !blocking) {
      closeModal();
    }
  }, [blocking, closeModal]);
  (0, _react.useEffect)(() => {
    if (openProp) {
      activatorRef.current = document.activeElement;
      setOpen(true);
    } else {
      closeModal();
    }
  }, [openProp, closeModal]);
  (0, _react.useEffect)(() => {
    document.addEventListener('keydown', handleKeyDown, false);
    return () => {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [handleKeyDown]);
  const handleIFrameLoad = (0, _react.useCallback)(evt => {
    const iframe = evt.target;

    if (iframe && iframe.contentWindow) {
      try {
        setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
      } catch {
        setIframeHeight(DEFAULT_IFRAME_CONTENT_HEIGHT);
      }
    }
  }, []);
  if (!open) return null;
  return /*#__PURE__*/_react.default.createElement(_Portal.Portal, null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Modal.default.Modal
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Modal.default.Backdrop, transitionClassName)
  }), /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Modal.default.Content, transitionClassName, {
      [_Modal.default['Content-isLong']]: long
    }),
    role: "dialog",
    "aria-labelledby": "id-of-the-header-title",
    "aria-modal": true,
    tabIndex: -1,
    ref: modalRef
  }, title && /*#__PURE__*/_react.default.createElement("header", {
    className: _Modal.default.Header,
    ref: titleBarRef
  }, /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
    level: 1
  }, title), !blocking && /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Modal.default.Button,
    onClick: () => closeModal(),
    "aria-label": translate('close') || 'Close'
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "close",
    size: "large"
  }))), isIFrameProps(props) ? /*#__PURE__*/_react.default.createElement("iframe", Object.assign({
    src: props.src,
    name: props.iFrameName,
    title: props.iFrameTitle || 'body markup',
    className: _Modal.default.IFrame
  }, iframeHeight && {
    style: {
      height: `${iframeHeight}px`
    }
  }, !long && {
    onLoad: handleIFrameLoad
  })) : /*#__PURE__*/_react.default.createElement("div", {
    className: _Modal.default.Body
  }, props.children))));
}