"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ProgressTrackerStep = ProgressTrackerStep;
exports.ProgressTrackerStepIcon = ProgressTrackerStepIcon;
exports.ProgressTrackerStepLabel = ProgressTrackerStepLabel;
exports.ProgressTrackerStepConnector = ProgressTrackerStepConnector;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../../../Icon");

var _TextBlock = require("../../../TextBlock");

var _VisuallyHidden = require("../../../VisuallyHidden");

var _hooks = require("../../hooks");

var _ProgressTrackerStep = _interopRequireDefault(require("./ProgressTrackerStep.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ProgressTrackerStep({
  children,
  description,
  icon,
  iconAppearance,
  id,
  label,
  state,
  stateHidden = true
}) {
  const {
    steps
  } = (0, _hooks.useProgressTracker)();
  const first = Object.keys(steps).indexOf(id) === 0;
  const {
    [id]: {
      active,
      completed
    }
  } = steps;
  const className = (0, _cssUtilities.classNames)(_ProgressTrackerStep.default.ProgressTrackerStep, completed && _ProgressTrackerStep.default.Completed);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !first && /*#__PURE__*/_react.default.createElement(ProgressTrackerStepConnector, {
    active: active,
    completed: completed
  }), /*#__PURE__*/_react.default.createElement("li", {
    className: className,
    "aria-current": active
  }, /*#__PURE__*/_react.default.createElement(ProgressTrackerStepIcon, {
    active: active,
    completed: completed,
    source: icon,
    appearance: iconAppearance
  }), /*#__PURE__*/_react.default.createElement(ProgressTrackerStepLabel, {
    active: active,
    completed: completed,
    description: description,
    label: label,
    state: state,
    stateHidden: stateHidden
  }), children));
}

function ProgressTrackerStepIcon({
  active,
  appearance = 'info',
  source,
  completed
}) {
  const className = (0, _cssUtilities.classNames)(_ProgressTrackerStep.default.ProgressTrackerStepIcon, active && _ProgressTrackerStep.default.active, completed && _ProgressTrackerStep.default.completed);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: source,
    appearance: active || completed ? appearance : 'subdued',
    size: "large"
  }));
}

function ProgressTrackerStepLabel({
  active,
  completed,
  description,
  label,
  state,
  stateHidden
}) {
  const className = (0, _cssUtilities.classNames)(_ProgressTrackerStep.default.ProgressTrackerStepLabel, (active || completed) && _ProgressTrackerStep.default.completed);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, stateHidden ? /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, state) : /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, null, state), /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, {
    emphasized: active || completed
  }, label)), (active || completed) && description && /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, {
    size: "small",
    subdued: true
  }, description));
}

function ProgressTrackerStepConnector({
  active,
  completed
}) {
  const className = (0, _cssUtilities.classNames)(_ProgressTrackerStep.default.ProgressTrackerStepConnector, (active || completed) && _ProgressTrackerStep.default.completed);
  return /*#__PURE__*/_react.default.createElement("li", {
    className: className,
    "aria-hidden": true
  });
}