"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _VisuallyHidden = require("../VisuallyHidden");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _Radio = require("./Radio");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  name: 'radio_button',
  children: 'Save this information for next time'
};
describe('<Radio />', () => {
  it('renders an un-checked radio and label', () => {
    const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, defaultProps));
    expect(radio).toContainReactComponent('input', {
      checked: false,
      type: 'radio'
    });
    expect(radio.find('label')).toContainReactText('Save this information for next time');
  });
  it('renders a checked radio when the checked prop is provided and set to true', () => {
    const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
      checked: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a checked radio when the value prop is provided and set to true', () => {
    const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
      value: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a disabled radio when the disabled prop is provided and set to true', () => {
    const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
      disabled: true
    })));
    expect(radio).toContainReactComponent('input', {
      disabled: true,
      type: 'radio'
    });
  });
  it('calls the onChange callback when the radio is checked and unchecked', () => {
    const onChangeSpy = jest.fn();
    const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
      onChange: onChangeSpy
    })));
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: true
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(true);
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: false
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(false);
  });
  describe('accessibilityLabel', () => {
    it('renders visually hidden content when the accessibilityLabel is set', () => {
      const accessibilityLabelContent = 'Accessibility content';
      const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
        accessibilityLabel: accessibilityLabelContent
      })));
      expect(radio.find(_VisuallyHidden.VisuallyHidden)).toContainReactText(accessibilityLabelContent);
    });
    it('hides the label for accessibility purposes when the accessibilityLabel is set', () => {
      const children = 'Basic label';
      const radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Radio.Radio, Object.assign({}, defaultProps, {
        accessibilityLabel: "Accessibility content"
      }), children));
      expect(radio.find(_HiddenForAccessibility.HiddenForAccessibility)).toContainReactText(children);
    });
  });
});