"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReviewItem = ReviewItem;
exports.ReviewBlock = ReviewBlock;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _id = require("../../utilities/id");

var _legacy = require("../../utilities/legacy");

var _Theme = require("../Theme");

var _HeadingGroup = require("../HeadingGroup");

var _ = require("..");

var _ReviewItem = _interopRequireDefault(require("./ReviewItem.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createId = (0, _id.createIdCreator)('ReviewBlock');

function ReviewItem({
  children,
  label,
  to,
  linkLabel,
  linkAriaLabel
}) {
  const {
    reviewBlock: {
      gap = 'none'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_ReviewItem.default.ReviewItem, gap !== 'none' && _ReviewItem.default.isContainer, _legacy.utilityDefaultBorderColor);
  const linkContent = linkAriaLabel ? /*#__PURE__*/_react.default.createElement(_.HiddenForAccessibility, null, linkLabel) : linkLabel;
  return /*#__PURE__*/_react.default.createElement("div", {
    role: "row",
    className: className,
    key: label
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _ReviewItem.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("div", {
    role: "rowheader",
    className: _ReviewItem.default.Label
  }, /*#__PURE__*/_react.default.createElement(_.Text, {
    subdued: true
  }, label)), /*#__PURE__*/_react.default.createElement("div", {
    role: "cell",
    className: _ReviewItem.default.Content
  }, children)), to && /*#__PURE__*/_react.default.createElement("div", {
    role: "cell"
  }, /*#__PURE__*/_react.default.createElement(_.Link, {
    to: to
  }, /*#__PURE__*/_react.default.createElement(_.Text, {
    size: "small"
  }, linkContent), linkAriaLabel && /*#__PURE__*/_react.default.createElement(_.VisuallyHidden, null, linkAriaLabel))));
}

function ReviewBlock({
  children,
  title,
  titleHidden
}) {
  const id = (0, _id.useId)(undefined, createId);
  const {
    reviewBlock: {
      background = 'transparent',
      gap = 'none'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_ReviewItem.default.ReviewBlock, background && _ReviewItem.default[(0, _cssUtilities.variationName)('ReviewBlock-background', background)], gap === 'none' && _ReviewItem.default.isContainer, _legacy.utilityDefaultBorderColor);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, titleHidden ? /*#__PURE__*/_react.default.createElement(_.VisuallyHidden, null, /*#__PURE__*/_react.default.createElement(_.TextBlock, {
    id: id
  }, title)) : /*#__PURE__*/_react.default.createElement(_.Heading, {
    id: id
  }, title), /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement("div", {
    "aria-labelledby": id,
    role: "table",
    className: className
  }, children)));
}