"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Select = Select;
exports.PLACEHOLDER_VALUE = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _InlineError = require("../InlineError");

var _Text = require("../Text");

var _Icon = require("../Icon");

var _Truncate = require("../Truncate");

var _BlockStack = require("../BlockStack");

var _InlineStack = require("../InlineStack");

var _Theme = require("../Theme");

var _autocomplete = require("../../utilities/autocomplete");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Select = _interopRequireDefault(require("./Select.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PLACEHOLDER_VALUE = '';
exports.PLACEHOLDER_VALUE = PLACEHOLDER_VALUE;
const createId = (0, _id.createIdCreator)('Select');

function Select({
  id: explicitId,
  name,
  label,
  labelPosition,
  options,
  value = PLACEHOLDER_VALUE,
  disabled,
  readonly,
  required,
  error,
  autocomplete,
  placeholder,
  onChange,
  border,
  background,
  disclosureIconSeparator
}) {
  const {
    select: {
      labelPosition: themeLabelPosition = 'inside',
      background: themeBackground = 'surfaceTertiary',
      border: themeBorder = 'full',
      borderColor = 'base',
      focusBorder = 'full',
      disclosureIcon = 'caretDown',
      disclosureIconSeparator: themeDisclosureIconSeparator = true,
      typographyStyle,
      errorIndentation,
      errorTypographyStyle
    },
    label: {
      typographyStyle: labelTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const finalLabelPosition = labelPosition !== null && labelPosition !== void 0 ? labelPosition : themeLabelPosition;
  const finalBorder = border !== null && border !== void 0 ? border : themeBorder;
  const finalDisclosureIconSeparator = disclosureIconSeparator !== null && disclosureIconSeparator !== void 0 ? disclosureIconSeparator : themeDisclosureIconSeparator;
  const finalBackground = background !== null && background !== void 0 ? background : themeBackground;
  const id = (0, _id.useId)(explicitId, createId);

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement("span", {
    className: (errorIndentation && _Select.default[(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles.default[errorTypographyStyle])
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  const className = (0, _cssUtilities.classNames)(_Select.default.Select, Boolean(error) && _Select.default.hasError, disabled && _Select.default['Select-isDisabled'], readonly && _Select.default['Select-isReadOnly'], _Select.default[(0, _cssUtilities.variationName)('Select-label', finalLabelPosition)], _Select.default[(0, _cssUtilities.variationName)('Select-background', finalBackground)], _Select.default[(0, _cssUtilities.variationName)('Select-border', finalBorder)], _Select.default[(0, _cssUtilities.variationName)('Select-borderColor', borderColor)], _Select.default[(0, _cssUtilities.variationName)('Select-focusBorder', focusBorder)], typographyStyle && _typographyStyles.default[typographyStyle]);

  const labelMarkup = /*#__PURE__*/_react.default.createElement("label", {
    className: (0, _cssUtilities.classNames)(_Select.default.Label, _Select.default[(0, _cssUtilities.variationName)('Label-position', finalLabelPosition)], {
      [_Select.default['Label-isPlaceholder']]: value === PLACEHOLDER_VALUE && placeholder === label
    }, background && _Select.default[(0, _cssUtilities.variationName)('Label-onBackground', background)]),
    htmlFor: id
  }, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    size: !(value === PLACEHOLDER_VALUE && placeholder === label) || finalLabelPosition === 'inside' ? 'small' : undefined,
    subdued: true,
    style: labelTypographyStyle
  }, /*#__PURE__*/_react.default.createElement(_Truncate.Truncate, null, label)));

  const view = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, finalLabelPosition === 'outside' || finalLabelPosition === 'inline' ? labelMarkup : null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Select.default.Wrapper
  }, finalLabelPosition === 'inside' && labelMarkup, /*#__PURE__*/_react.default.createElement("select", {
    name: name,
    id: id,
    disabled: disabled,
    onChange: event => onChange === null || onChange === void 0 ? void 0 : onChange(event.target.value),
    required: required,
    value: value,
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": Boolean(error),
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete)
  }, placeholder && (value === PLACEHOLDER_VALUE || placeholder !== label) && /*#__PURE__*/_react.default.createElement("option", {
    value: PLACEHOLDER_VALUE,
    hidden: placeholder === label,
    disabled: true
  }, placeholder === label ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "\xA0") : placeholder), options.map(option => /*#__PURE__*/_react.default.createElement("option", {
    key: option.value,
    value: option.value,
    disabled: option.disabled || readonly
  }, option.label))), /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Select.default.Selector, finalDisclosureIconSeparator && _Select.default['Selector-separated'], finalDisclosureIconSeparator && _Select.default[(0, _cssUtilities.variationName)('Selector-borderColor', borderColor)])
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: disclosureIcon,
    size: "small"
  }))));

  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, finalLabelPosition === 'inline' ? /*#__PURE__*/_react.default.createElement(_InlineStack.InlineStack, {
    spacing: "xtight",
    alignment: "center"
  }, view) : /*#__PURE__*/_react.default.createElement(_View.View, null, view), errorMarkup);
}