"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Text = Text;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _legacy = require("../../utilities/legacy");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Text = _interopRequireDefault(require("./Text.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Text({
  children,
  size,
  emphasized,
  subdued,
  appearance,
  role,
  style,
  id
}) {
  const className = (0, _cssUtilities.classNames)(_Text.default.Text, emphasized && _Text.default.emphasized, emphasized && _legacy.utilityDefaultTextColorEmphasized, subdued && _Text.default.subdued, subdued && _legacy.utilityDefaultTextColorSubdued, size && _Text.default[(0, _cssUtilities.variationName)('size', size)], appearance && _Text.default[(0, _cssUtilities.variationName)('appearance', appearance)], appearance && appearance === 'accent' && _legacy.utilityDefaultColorAccent, style && _typographyStyles.default[style]);
  const content = emphasized ? /*#__PURE__*/_react.default.createElement("strong", null, children) : children;
  const defaultProps = {
    className,
    id
  };

  if (typeof role === 'string') {
    switch (role) {
      case 'address':
        return /*#__PURE__*/_react.default.createElement("address", defaultProps, content);

      case 'deletion':
        return /*#__PURE__*/_react.default.createElement("del", defaultProps, content);

      default:
        throw new Error('Invalid Text’s role');
    }
  }

  if (typeof role === 'object') {
    switch (role.type) {
      case 'abbreviation':
        return /*#__PURE__*/_react.default.createElement("abbr", Object.assign({
          defaultProps,
          className: (0, _cssUtilities.classNames)(className, _Text.default.Abbr)
        }, {
          title: role.for
        }), content);

      case 'directional-override':
        return /*#__PURE__*/_react.default.createElement("bdo", Object.assign({}, defaultProps, {
          dir: role.direction
        }), content);

      case 'datetime':
        return /*#__PURE__*/_react.default.createElement("time", Object.assign({}, defaultProps, {
          dateTime: role.machineReadable
        }), content);

      default:
        throw new Error('Invalid Text’s role');
    }
  }

  return emphasized ? /*#__PURE__*/_react.default.createElement("strong", defaultProps, children) : /*#__PURE__*/_react.default.createElement("span", defaultProps, children);
}