"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _Text = require("./Text");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Text />', () => {
  describe('children', () => {
    it('renders the children', () => {
      const content = 'Snowdevil';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, null, content));
      expect(text).toContainReactText(content);
    });
    it('renders a <span> tag by default', () => {
      const content = 'Snowdevil';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, null, content));
      expect(text).toContainReactComponent('span');
    });
  });
  describe('emphasized', () => {
    it('renders a <strong>', () => {
      const content = 'Snowdevil';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        emphasized: true
      }, content));
      expect(text).toContainReactComponent('strong');
    });
  });
  describe('role', () => {
    it('renders an <address> tag when role is "address"', () => {
      const content = 'Snowdevil';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        role: "address"
      }, content));
      expect(text).toContainReactComponent('address');
    });
    it('renders a <del> tag when role is "deletion"', () => {
      const children = 'Snowdevil';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        role: "deletion"
      }, children));
      expect(text).toContainReactComponent('del', {
        children
      });
    });
    it('renders an <abbr> tag when role type is "abbr"', () => {
      const children = 'GMV';
      const title = 'Gross Merchandise Volume';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        role: {
          type: 'abbreviation',
          for: title
        }
      }, children));
      expect(text).toContainReactComponent('abbr', {
        children,
        title
      });
    });
    it('renders a <bdo> tag when role type is "directional-override"', () => {
      const children = 'info@shopify.com';
      const dir = 'ltr';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        role: {
          type: 'directional-override',
          direction: dir
        }
      }, children));
      expect(text).toContainReactComponent('bdo', {
        children,
        dir
      });
    });
    it('renders a <time> tag when role type is "datetime"', () => {
      const children = 'May 20th, 2020';
      const dateTime = '2020-05-20';
      const text = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Text.Text, {
        role: {
          type: 'datetime',
          machineReadable: dateTime
        }
      }, children));
      expect(text).toContainReactComponent('time', {
        children,
        dateTime
      });
    });
  });
});