"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.themeWithKnobs = themeWithKnobs;

var _react = _interopRequireDefault(require("react"));

var _addonKnobs = require("@storybook/addon-knobs");

var _hsluv = require("hsluv");

var _ = require("..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Group;

(function (Group) {
  Group["TextField"] = "Text field";
  Group["Select"] = "Select";
  Group["Breadcrumb"] = "Breadcrumb";
  Group["Actions"] = "Actions";
  Group["HeadingLevel1"] = "Heading level 1";
  Group["HeadingLevel2"] = "Heading level 2";
  Group["HeadingLevel3"] = "Heading level 3";
  Group["Checkbox"] = "Checkbox";
  Group["PrimaryButton"] = "Primary button";
  Group["SecondaryButton"] = "Secondary button";
  Group["FormLayout"] = "Form layout";
  Group["Tag"] = "Tag";
  Group["Tooltip"] = "Tooltip";
  Group["Banner"] = "Banner";
  Group["OptionList"] = "Option list";
  Group["Style"] = "Style";
  Group["Color"] = "Color";
  Group["Typography"] = "Typography";
  Group["Thumbnail"] = "Thumbnail";
})(Group || (Group = {}));

var Label;

(function (Label) {
  Label["Border"] = "Border";
  Label["BorderRadius"] = "Border radius";
  Label["LabelPosition"] = "Label position";
  Label["Style"] = "Style";
  Label["ErrorIndentation"] = "Error indentation";
  Label["BlockPadding"] = "Block padding";
  Label["InlinePadding"] = "Inline padding";
  Label["LoadingStyle"] = "Loading style";
  Label["BadgeColor"] = "Badge color";
})(Label || (Label = {}));

var Action;

(function (Action) {
  Action["Display"] = "Display";
})(Action || (Action = {}));

var Breadcrumb;

(function (Breadcrumb) {
  Breadcrumb["Gap"] = "Gap";
  Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
  Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));

const SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
const BORDER_RADIUS_OPTIONS = optionify(['none', 'tight', 'base', 'fullyRounded']);
const SIMPLE_BORDER_OPTIONS = optionify(['full', 'none']);
const BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
const LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
const ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
const BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
const NUMBER_STYLE_OPTIONS = optionify(['none', 'decimal', 'decimalLeadingZero']);
const STYLE_OPTIONS = optionify(['style1']);
const SIZE_OPTIONS = optionify(['base', 'xsmall', 'small', 'medium', 'large', 'xlarge', 'xxlarge']);
const LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
const FONT_OPTIONS = optionify(['primary', 'secondary']);
const WEIGHT_OPTIONS = optionify(['base', 'bold']);
const LINE_SIZE_OPTIONS = optionify(['base', 'large']);
const KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);
const SPACING_OPTIONS = optionify(['none', 'tight4x', 'tight3x', 'tight2x', 'tight1x', 'tight', 'base', 'loose', 'loose1x', 'loose2x', 'loose3x', 'loose4x']);
const SIMPLE_SPACING_OPTIONS = optionify(['tight', 'base']);
const LOADING_STYLE_OPTIONS = optionify(['spinner', 'progressBar']);
const ERROR_INDENTATION_OPTIONS = optionify(['none', 'toText']);
const OPACITY_OPTIONS = optionify(['translucent', 'opaque']);
const TEXT_ALIGNMENT_OPTIONS = optionify(['start', 'center']);
const OPTION_LIST_BORDER_OPTIONS = optionify(['full', 'none', 'inner']);
const BORDER_STYLE_OPTIONS = optionify(['base', 'dotted']);
const UNDEFINED = '';
const FONT_WEIGHT_OPTIONS = optionify(['100', '200', '300', '400', '500', '600', '700', '800', '900']);
const BADGE_COLOR_OPTIONS = optionify(['subdued', 'primary']);

function themeWithKnobs(...picks) {
  return storyFn => /*#__PURE__*/_react.default.createElement(ThemeWithKnobs, {
    pick: picks
  }, storyFn());
}

function ThemeWithKnobs({
  pick = [],
  children
}) {
  const textFields = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined
  };
  const selects = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined
  };
  const actions = {
    display: undefined
  };
  const buyerJourney = {
    gap: undefined,
    chevronIconSeparator: true,
    numberStyle: undefined,
    typographyStyle: undefined
  };
  const headingLevel1 = {
    typographyStyle: undefined
  };
  const headingLevel2 = {
    typographyStyle: undefined
  };
  const headingLevel3 = {
    typographyStyle: undefined
  };
  const checkbox = {
    borderRadius: undefined,
    errorIndentation: undefined
  };
  const primaryButton = {
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  const secondaryButton = {
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  const formLayout = {
    spacing: undefined
  };
  const tag = {
    borderRadius: undefined
  };
  const tooltip = {
    borderRadius: undefined,
    opacity: undefined,
    textAlignment: undefined
  };
  const banner = {
    border: undefined,
    borderRadius: undefined
  };
  const thumbnail = {
    aspectRatio: 1,
    border: undefined,
    badgeBackground: undefined
  };
  const optionList = {
    border: undefined,
    borderRadius: undefined,
    borderStyle: undefined,
    gap: undefined,
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined
  };

  if (pick.includes('textFields')) {
    textFields.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, textFields.border, Group.TextField);
    textFields.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFields.labelPosition, Group.TextField);
    textFields.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, textFields.errorIndentation, Group.TextField);
  }

  if (pick.includes('select')) {
    selects.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, selects.border, Group.Select);
    selects.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, selects.labelPosition, Group.Select);
    selects.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, selects.errorIndentation, Group.Select);
  }

  if (pick.includes('actions')) {
    actions.display = (0, _addonKnobs.select)(Action.Display, ACTIONS_DISPLAY_OPTIONS, actions.display, Group.Actions);
  }

  if (pick.includes('buyerJourney')) {
    buyerJourney.gap = (0, _addonKnobs.select)(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, buyerJourney.gap, Group.Breadcrumb);
    buyerJourney.chevronIconSeparator = (0, _addonKnobs.boolean)(Breadcrumb.ChevronIconSeparator, buyerJourney.chevronIconSeparator, Group.Breadcrumb);
    buyerJourney.numberStyle = (0, _addonKnobs.select)(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, buyerJourney.numberStyle, Group.Breadcrumb);
    buyerJourney.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, buyerJourney.typographyStyle, Group.Breadcrumb);
  }

  if (pick.includes('checkbox')) {
    checkbox.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, SIMPLE_BORDER_RADIUS_OPTIONS, checkbox.borderRadius, Group.Checkbox);
    checkbox.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, checkbox.errorIndentation, Group.Checkbox);
  }

  if (pick.includes('banner')) {
    banner.border = (0, _addonKnobs.select)(Label.Border, SIMPLE_BORDER_OPTIONS, banner.border, Group.Banner);
    banner.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, banner.borderRadius, Group.Banner);
  }

  if (pick.includes('thumbnail')) {
    thumbnail.aspectRatio = (0, _addonKnobs.number)('Aspect ratio', 1, {
      min: 0
    }, Group.Thumbnail);
    thumbnail.border = (0, _addonKnobs.select)(Label.Border, SIMPLE_BORDER_OPTIONS, thumbnail.border, Group.Thumbnail);
    thumbnail.badgeBackground = (0, _addonKnobs.select)(Label.BadgeColor, BADGE_COLOR_OPTIONS, thumbnail.badgeBackground, Group.Thumbnail);
  }

  if (pick.includes('optionList')) {
    optionList.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, optionList.borderRadius, Group.OptionList);
    optionList.border = (0, _addonKnobs.select)(Label.Border, OPTION_LIST_BORDER_OPTIONS, optionList.border, Group.OptionList);
    optionList.borderStyle = (0, _addonKnobs.select)('Border style', BORDER_STYLE_OPTIONS, optionList.borderStyle, Group.OptionList);
    optionList.gap = (0, _addonKnobs.select)('Gap', optionify(['none', 'tight', 'base']), optionList.gap, Group.OptionList);
    optionList.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, optionList.blockPadding, Group.OptionList);
    optionList.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, optionList.inlinePadding, Group.OptionList);
    optionList.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, optionList.typographyStyle, Group.OptionList);
  }

  if (pick.includes('headingLevel1')) {
    headingLevel1.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel1.typographyStyle, Group.HeadingLevel1);
  }

  if (pick.includes('headingLevel2')) {
    headingLevel2.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel2.typographyStyle, Group.HeadingLevel2);
  }

  if (pick.includes('headingLevel3')) {
    headingLevel3.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel3.typographyStyle, Group.HeadingLevel3);
  }

  if (pick.includes('primaryButton')) {
    primaryButton.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, primaryButton.typographyStyle, Group.PrimaryButton);
    primaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, primaryButton.blockPadding, Group.PrimaryButton);
    primaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, primaryButton.inlinePadding, Group.PrimaryButton);
    primaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, primaryButton.loadingStyle, Group.PrimaryButton);
  }

  if (pick.includes('secondaryButton')) {
    secondaryButton.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, secondaryButton.typographyStyle, Group.SecondaryButton);
    secondaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, secondaryButton.blockPadding, Group.SecondaryButton);
    secondaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, secondaryButton.inlinePadding, Group.SecondaryButton);
    secondaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, secondaryButton.loadingStyle, Group.SecondaryButton);
  }

  if (pick.includes('formLayout')) {
    formLayout.spacing = (0, _addonKnobs.select)('Spacing', SIMPLE_SPACING_OPTIONS, formLayout.spacing, Group.FormLayout);
  }

  if (pick.includes('tag')) {
    tag.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tag.borderRadius, Group.Tag);
  }

  if (pick.includes('tooltip')) {
    tooltip.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tooltip.borderRadius, Group.Tooltip);
    tooltip.opacity = (0, _addonKnobs.select)('Opacity', OPACITY_OPTIONS, tooltip.opacity, Group.Tooltip);
    tooltip.textAlignment = (0, _addonKnobs.select)('Text alignment', TEXT_ALIGNMENT_OPTIONS, tooltip.textAlignment, Group.Tooltip);
  }

  const theme = (0, _.createTheme)({
    textFields,
    select: selects,
    actions,
    buyerJourney,
    headingLevel1,
    headingLevel2,
    headingLevel3,
    checkbox,
    primaryButton,
    secondaryButton,
    formLayout,
    tag,
    tooltip,
    banner,
    thumbnail,
    optionList,
    typographyStyle1: {
      size: (0, _addonKnobs.select)(`Size`, SIZE_OPTIONS, undefined, Group.Style),
      letterCase: (0, _addonKnobs.select)(`Letter case`, LETTER_CASE_OPTIONS, undefined, Group.Style),
      fonts: (0, _addonKnobs.select)(`Font`, FONT_OPTIONS, undefined, Group.Style),
      weight: (0, _addonKnobs.select)(`Weight`, WEIGHT_OPTIONS, undefined, Group.Style),
      lineSize: (0, _addonKnobs.select)(`Line size`, LINE_SIZE_OPTIONS, undefined, Group.Style),
      kerning: (0, _addonKnobs.select)(`Kerning`, KERNING_OPTIONS, undefined, Group.Style)
    },
    typographyScale: {
      base: (0, _addonKnobs.number)('Base size', 14, {}, Group.Typography),
      ratio: (0, _addonKnobs.number)('Scale ratio', 1.285, {
        step: 0.001
      }, Group.Typography)
    },
    typographyPrimary: {
      fonts: (0, _addonKnobs.text)('Primary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Primary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Primary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    typographySecondary: {
      fonts: (0, _addonKnobs.text)('Secondary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Secondary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Secondary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    colors: {
      canvas: hsluvColorGroup('Canvas'),
      surfacePrimary: hsluvColorGroup('Surface primary'),
      surfaceSecondary: hsluvColorGroup('Surface secondary'),
      surfaceTertiary: hsluvColorGroup('Surface tertiary'),
      primaryAction: hsluvColorGroup('Primary action'),
      secondaryAction: hsluvColorGroup('Secondary action'),
      tertiaryAction: hsluvColorGroup('Tertiary action'),
      interactive: hsluvColorGroup('Interactive'),
      info: hsluvColorGroup('Info'),
      success: hsluvColorGroup('Success'),
      warning: hsluvColorGroup('Warning'),
      critical: hsluvColorGroup('Critical')
    }
  });
  return /*#__PURE__*/_react.default.createElement(_.Theme, {
    theme: theme
  }, children);
}

function optionify(array) {
  return array.reduce((acc, value) => ({ ...acc,
    [value]: value
  }), {
    ' ': undefined
  });
}

function toHsluv(str) {
  if (str === UNDEFINED) return undefined;
  const rgb = str.slice(5, -1).split(',').slice(0, 3).map(Number).map(num => num / 255);
  return (0, _hsluv.rgbToHsluv)(rgb);
}

function hsluvColor(name) {
  return toHsluv((0, _addonKnobs.color)(name, UNDEFINED, Group.Color));
}

function hsluvColorGroup(name) {
  return {
    background: hsluvColor(`${name} background`),
    foreground: hsluvColor(`${name} foreground`),
    accent: hsluvColor(`${name} accent`)
  };
}