"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Banner = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const id_1 = require("../../utilities/id");
const AppContext_1 = require("../AppContext");
const Heading_1 = require("../Heading");
const HeadingGroup_1 = require("../HeadingGroup");
const Bookend_1 = require("../Bookend");
const Icon_1 = require("../Icon");
const View_1 = require("../View");
const TextContainer_1 = require("../TextContainer");
const Banner_css_1 = __importDefault(require("./Banner.css"));
const createId = id_1.createIdCreator('Banner');
function Banner({ children, collapsible = false, iconHidden = false, status = 'info', title, autofocus = false, }) {
    const translate = AppContext_1.useTranslate();
    const [collapsed, setCollapsed] = react_1.useState(true);
    const bannerRef = react_1.useRef(null);
    react_1.useEffect(() => {
        var _a;
        if (autofocus === true) {
            (_a = bannerRef === null || bannerRef === void 0 ? void 0 : bannerRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }, [autofocus]);
    const className = css_utilities_1.classNames(Banner_css_1.default.Banner, status && Banner_css_1.default[css_utilities_1.variationName('status', status)]);
    const id = id_1.useId(undefined, createId);
    const controlId = collapsed ? undefined : id;
    const showChildren = !collapsible || (collapsible && !collapsed);
    return (<div className={className} role={status === 'critical' ? 'alert' : 'status'} aria-atomic="true" aria-live="polite" {...(autofocus && { tabIndex: -1 })} ref={bannerRef}>
      <Bookend_1.Bookend leading={!iconHidden} trailing={collapsible}>
        {!iconHidden && (<div className={Banner_css_1.default.Icon}>
            <Icon_1.Icon source={status}/>
          </div>)}
        <TextContainer_1.TextContainer spacing="tight">
          {title && <Heading_1.Heading level={3}>{title}</Heading_1.Heading>}
          {children && showChildren && (<div className={Banner_css_1.default.Content} id={controlId}>
              <HeadingGroup_1.HeadingGroup>
                <View_1.View>{children}</View_1.View>
              </HeadingGroup_1.HeadingGroup>
            </div>)}
        </TextContainer_1.TextContainer>
        {collapsible && (<View_1.View>
            <button type="button" className={Banner_css_1.default.Button} onClick={() => setCollapsed((collapsed) => !collapsed)} aria-pressed={!collapsed} aria-expanded={!collapsed} aria-controls={controlId}>
              <Icon_1.Icon size="small" source={collapsed ? 'chevronDown' : 'chevronUp'} accessibilityLabel={translate('expand')}/>
            </button>
          </View_1.View>)}
      </Bookend_1.Bookend>
    </div>);
}
exports.Banner = Banner;
