"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const AppContext_1 = require("../AppContext");
const transition_1 = require("../../utilities/transition");
const Spinner_1 = require("../Spinner");
const Link_1 = require("../Link");
const legacy_1 = require("../../utilities/legacy");
const media_query_1 = require("../../utilities/media-query");
const Connected_1 = require("../Connected");
const Theme_1 = require("../Theme");
const typography_styles_css_1 = __importDefault(require("../../utilities/typography-styles.css"));
const Button_css_1 = __importDefault(require("./Button.css"));
exports.Button = react_1.forwardRef(({ children, submit = false, disabled, onPress, to, subdued, plain, secondary, loading = false, fill = false, loadingLabel, underline, }, ref) => {
    const href = disabled ? undefined : to;
    const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
    const refsSetter = react_1.useCallback((instance) => {
        if (typeof ref === 'function') {
            ref(instance);
        }
        else if (ref) {
            ref.current = instance;
        }
    }, [ref]);
    const translate = AppContext_1.useTranslate();
    const prefersReducedMotion = media_query_1.usePrefersReducedMotion();
    const transition = transition_1.useTransition(loading, {
        enter: 'slow',
    });
    const connected = Connected_1.useConnected();
    const { primaryButton: { typographyStyle: primaryStyle, loadingStyle: primaryLoading = 'spinner', }, secondaryButton: { typographyStyle: secondaryStyle, loadingStyle: secondaryLoading = 'spinner', }, } = Theme_1.useThemeConfiguration();
    const loadingStyle = secondary ? secondaryLoading : primaryLoading;
    const classes = css_utilities_1.classNames(Button_css_1.default.Button, legacy_1.button, subdued && Button_css_1.default.isSubdued, plain && Button_css_1.default.isPlain, plain && underline && Button_css_1.default.isUnderline, disabled && Button_css_1.default.isDisabled, loading && loadingStyle === 'spinner' && Button_css_1.default.isLoading, fill && Button_css_1.default.isFill, loading &&
        loadingStyle === 'spinner' &&
        Button_css_1.default[css_utilities_1.variationName('isLoading-transition', transition)], connected && Button_css_1.default.isConnected, secondary && Button_css_1.default.isSecondary, loading && loadingStyle === 'progressBar' && Button_css_1.default[loadingStyle]);
    const normalizedLoadingLabel = loadingLabel
        ? loadingLabel
        : translate('processing');
    const contentTypography = secondary
        ? secondaryStyle && typography_styles_css_1.default[secondaryStyle]
        : primaryStyle && typography_styles_css_1.default[primaryStyle];
    const content = (<span className={css_utilities_1.classNames(Button_css_1.default.Content, contentTypography)}>
        {loading && loadingStyle === 'progressBar' && prefersReducedMotion
        ? normalizedLoadingLabel
        : children}
      </span>);
    const type = submit ? 'submit' : 'button';
    const loadingMarkup = (<span className={css_utilities_1.classNames(Button_css_1.default.LoadingContent, !prefersReducedMotion && Button_css_1.default.Spinner)}>
        <Spinner_1.Spinner size="small" color="inherit">
          {normalizedLoadingLabel}
        </Spinner_1.Spinner>
      </span>);
    if (href) {
        return (<Link_1.UnstyledLink to={href} className={classes} onPress={onPress}>
          {content}
          {loading && loadingStyle === 'spinner' && loadingMarkup}
        </Link_1.UnstyledLink>);
    }
    return (<button type={type} className={classes} disabled={disabled || loading} onClick={onClick} aria-busy={loading} ref={refsSetter}>
        {content}
        {loading && loadingStyle === 'spinner' && loadingMarkup}
      </button>);
});
