"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MoneyLineSeparator = exports.MoneyLine = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const InlineStack_1 = require("../InlineStack");
const Text_1 = require("../Text");
const Theme_1 = require("../Theme");
const MoneyLine_css_1 = __importDefault(require("./MoneyLine.css"));
function MoneyLine({ label, value, subdued, children }) {
    const { moneyLines: { background, inlineAlignment, labelTypographyStyle, valueTypographyStyle, }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(MoneyLine_css_1.default.MoneyLine, background && MoneyLine_css_1.default[css_utilities_1.variationName('background', background)], inlineAlignment &&
        MoneyLine_css_1.default[css_utilities_1.variationName('inlineAlignment', inlineAlignment)]);
    return (<div className={className} role="row">
      <div className={MoneyLine_css_1.default.Label} role="rowheader">
        <InlineStack_1.InlineStack spacing="tight">
          <Text_1.Text style={labelTypographyStyle}>{label}</Text_1.Text>
        </InlineStack_1.InlineStack>
      </div>
      <div className={MoneyLine_css_1.default.Value} role="cell">
        <InlineStack_1.InlineStack spacing="tight">
          <Text_1.Text subdued={subdued} emphasized={!subdued} size={subdued ? 'small' : undefined} style={valueTypographyStyle}>
            {value}
          </Text_1.Text>
          {children}
        </InlineStack_1.InlineStack>
      </div>
    </div>);
}
exports.MoneyLine = MoneyLine;
function MoneyLineSeparator() {
    return <div className={MoneyLine_css_1.default.MoneyLineSeparator}/>;
}
exports.MoneyLineSeparator = MoneyLineSeparator;
