"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../test-utilities");
const MoneySummary_1 = require("./MoneySummary");
const defaultProps = {
    label: faker_1.default.random.word(),
    value: faker_1.default.finance.amount(),
    prefix: faker_1.default.finance.currencyCode(),
};
describe('<MoneySummary />', () => {
    it('renders a label', () => {
        const label = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary {...defaultProps} label={label}/>);
        expect(moneySummary).toContainReactText(label);
    });
    it('renders a prefix', () => {
        const prefix = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary {...defaultProps} prefix={prefix}/>);
        expect(moneySummary).toContainReactText(prefix);
    });
    it('renders a value', () => {
        const value = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary {...defaultProps} value={value}/>);
        expect(moneySummary).toContainReactText(value);
    });
    it('renders children', () => {
        const children = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary {...defaultProps}>{children}</MoneySummary_1.MoneySummary>);
        expect(moneySummary).toContainReactText(children);
    });
});
