"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionSecondaryContent = exports.OptionPrimaryContent = exports.Option = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Bookend_1 = require("../../../Bookend");
const VisuallyHidden_1 = require("../../../VisuallyHidden");
const Text_1 = require("../../../Text");
const Radio_1 = require("../../../Radio");
const Checkbox_1 = require("../../../Checkbox");
const Theme_1 = require("../../../Theme");
const hooks_1 = require("../../hooks");
const OptionList_css_1 = __importDefault(require("../../OptionList.css"));
function Option({ id, label, details, children }) {
    const { id: optionListId, selectedItems, allowMultiple, onChange, } = hooks_1.useOptionList();
    const Control = allowMultiple ? Checkbox_1.CheckboxControl : Radio_1.RadioControl;
    const checked = selectedItems.includes(id);
    const { optionList: { gap = 'none', typographyStyle }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(OptionList_css_1.default.Option, gap !== 'none' && OptionList_css_1.default.isContainer);
    function getNewSelections() {
        if (!allowMultiple) {
            return [id];
        }
        if (checked) {
            return selectedItems.filter((selectedItem) => selectedItem !== id);
        }
        return [...selectedItems, id];
    }
    return (<div className={className}>
      <label htmlFor={`${optionListId}-${id}`} className={OptionList_css_1.default.OptionLabel}>
        <Bookend_1.Bookend leading>
          <Control id={`${optionListId}-${id}`} name={`${optionListId}`} checked={checked} onChange={() => onChange(getNewSelections())}/>

          {label && children ? (<>
              <VisuallyHidden_1.VisuallyHidden>{label}</VisuallyHidden_1.VisuallyHidden>
              <div aria-hidden="true">
                <Bookend_1.Bookend trailing>{children}</Bookend_1.Bookend>
              </div>
            </>) : (<Text_1.Text emphasized={typographyStyle == null} style={typographyStyle}>
              {label}
            </Text_1.Text>)}
        </Bookend_1.Bookend>
      </label>
      {details}
    </div>);
}
exports.Option = Option;
function OptionPrimaryContent({ children }) {
    return <div className={OptionList_css_1.default.PrimaryContent}>{children}</div>;
}
exports.OptionPrimaryContent = OptionPrimaryContent;
function OptionSecondaryContent({ children, }) {
    return <div className={OptionList_css_1.default.SecondaryContent}>{children}</div>;
}
exports.OptionSecondaryContent = OptionSecondaryContent;
