import { ReactNode } from 'react';
import { Placement } from './utilities/offsets';
export interface Props {
    children?: ReactNode;
    /**
     * The element used to activate the popper.
     */
    activator: HTMLElement | null;
    /**
     * Position the popper relative to the activator.
     * @default 'blockStart'
     */
    placement?: Placement;
    /**
     * Moves the popper away from the activator.
     * If not specified, the popper will be flush with the activator.
     *
     * Number is in pixels.
     *
     * Example:
     * - `10` represents `10px`
     */
    offset?: number;
    /**
     * Ensures the popper is always visible in the viewport.
     */
    preventOverflow?: boolean;
    /**
     * Match the inline size of the popper to the `activator` size.
     */
    sameInlineSize?: boolean;
    /**
     * Minimum inline size of the popper.
     * This ensure the popper will not go smaller than the size specified.
     *
     * When used with `sameInlineSize`, the `minInlineSize` will act as a
     * guard rail in case the activator becomes too small depending its context.
     * This will ensure the popper content remains readable.
     *
     * Number is in pixels.
     *
     * Example:
     * - `500` represents `500px`
     */
    minInlineSize?: number;
}
export declare function Popper({ children, offset, placement, preventOverflow, activator, sameInlineSize, minInlineSize, }: Props): JSX.Element;
