"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgressTrackerStepConnector = exports.ProgressTrackerStepLabel = exports.ProgressTrackerStepIcon = exports.ProgressTrackerStep = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Icon_1 = require("../../../Icon");
const TextBlock_1 = require("../../../TextBlock");
const VisuallyHidden_1 = require("../../../VisuallyHidden");
const hooks_1 = require("../../hooks");
const ProgressTrackerStep_css_1 = __importDefault(require("./ProgressTrackerStep.css"));
function ProgressTrackerStep({ children, description, icon, iconAppearance, id, label, state, stateHidden = true, }) {
    const { steps } = hooks_1.useProgressTracker();
    const first = Object.keys(steps).indexOf(id) === 0;
    const { [id]: { active, completed }, } = steps;
    const className = css_utilities_1.classNames(ProgressTrackerStep_css_1.default.ProgressTrackerStep, completed && ProgressTrackerStep_css_1.default.Completed);
    return (<>
      {!first && (<ProgressTrackerStepConnector active={active} completed={completed}/>)}
      <li className={className} aria-current={active}>
        <ProgressTrackerStepIcon active={active} completed={completed} source={icon} appearance={iconAppearance}/>
        <ProgressTrackerStepLabel active={active} completed={completed} description={description} label={label} state={state} stateHidden={stateHidden}/>
        {children}
      </li>
    </>);
}
exports.ProgressTrackerStep = ProgressTrackerStep;
function ProgressTrackerStepIcon({ active, appearance = 'info', source, completed, }) {
    const className = css_utilities_1.classNames(ProgressTrackerStep_css_1.default.ProgressTrackerStepIcon, active && ProgressTrackerStep_css_1.default.active, completed && ProgressTrackerStep_css_1.default.completed);
    return (<div className={className}>
      <Icon_1.Icon source={source} appearance={active || completed ? appearance : 'subdued'} size="large"/>
    </div>);
}
exports.ProgressTrackerStepIcon = ProgressTrackerStepIcon;
function ProgressTrackerStepLabel({ active, completed, description, label, state, stateHidden, }) {
    const className = css_utilities_1.classNames(ProgressTrackerStep_css_1.default.ProgressTrackerStepLabel, (active || completed) && ProgressTrackerStep_css_1.default.completed);
    return (<>
      <div className={className}>
        {stateHidden ? (<VisuallyHidden_1.VisuallyHidden>{state}</VisuallyHidden_1.VisuallyHidden>) : (<TextBlock_1.TextBlock>{state}</TextBlock_1.TextBlock>)}
        <TextBlock_1.TextBlock emphasized={active || completed}>{label}</TextBlock_1.TextBlock>
      </div>
      {(active || completed) && description && (<TextBlock_1.TextBlock size="small" subdued>
          {description}
        </TextBlock_1.TextBlock>)}
    </>);
}
exports.ProgressTrackerStepLabel = ProgressTrackerStepLabel;
function ProgressTrackerStepConnector({ active, completed, }) {
    const className = css_utilities_1.classNames(ProgressTrackerStep_css_1.default.ProgressTrackerStepConnector, (active || completed) && ProgressTrackerStep_css_1.default.completed);
    return <li className={className} aria-hidden/>;
}
exports.ProgressTrackerStepConnector = ProgressTrackerStepConnector;
