"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const dom_1 = require("@quilted/react-testing/dom");
const TextBlock_1 = require("../../../TextBlock");
const ProgressTracker_1 = require("../../ProgressTracker");
const VisuallyHidden_1 = require("../../../VisuallyHidden");
const ProgressTrackerStep_1 = require("./ProgressTrackerStep");
const defaultProps = (id) => ({
    id: `step${id}`,
    icon: 'checkmark',
    label: `Step ${id}`,
    state: `State ${id}`,
});
describe('<ProgressTrackerStep />', () => {
    it('renders a <ProgressTrackerStepConnector /> except for first ProgressTrackerStep', () => {
        const progressTracker = dom_1.mount(<ProgressTracker_1.ProgressTracker activeStep="step3">
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(1)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(2)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(3)}/>
      </ProgressTracker_1.ProgressTracker>);
        const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep,] = progressTracker.findAll(ProgressTrackerStep_1.ProgressTrackerStep);
        expect(firstProgressTrackerStep).not.toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepConnector);
        expect(secondProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepConnector, {
            active: false,
            completed: true,
        });
        expect(finalProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepConnector, {
            active: true,
            completed: false,
        });
    });
    it('renders <ProgressTrackerStepIcon />', () => {
        const progressTracker = dom_1.mount(<ProgressTracker_1.ProgressTracker activeStep="step2">
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(1)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(2)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(3)} iconAppearance="critical"/>
      </ProgressTracker_1.ProgressTracker>);
        const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep,] = progressTracker.findAll(ProgressTrackerStep_1.ProgressTrackerStep);
        expect(firstProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepIcon, {
            active: false,
            completed: true,
            source: 'checkmark',
        });
        expect(secondProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepIcon, {
            active: true,
            completed: false,
            source: 'checkmark',
        });
        expect(finalProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepIcon, {
            active: false,
            completed: false,
            source: 'checkmark',
            appearance: 'critical',
        });
    });
    it('renders <ProgressTrackerStepLabel /> with state', () => {
        const progressTracker = dom_1.mount(<ProgressTracker_1.ProgressTracker>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(1)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(2)} stateHidden={false}/>
      </ProgressTracker_1.ProgressTracker>);
        const [firstProgressTrackerStep, finalProgressTrackerStep,] = progressTracker.findAll(ProgressTrackerStep_1.ProgressTrackerStep);
        expect(firstProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepLabel, {
            state: 'State 1',
        });
        expect(finalProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepLabel, {
            state: 'State 2',
        });
        expect(firstProgressTrackerStep).toContainReactComponent(VisuallyHidden_1.VisuallyHidden);
        expect(firstProgressTrackerStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 1);
        expect(finalProgressTrackerStep).not.toContainReactComponent(VisuallyHidden_1.VisuallyHidden);
        expect(finalProgressTrackerStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(firstProgressTrackerStep.find(VisuallyHidden_1.VisuallyHidden)).toContainReactText('State 1');
        expect(finalProgressTrackerStep.find(TextBlock_1.TextBlock)).toContainReactText('State 2');
    });
    it('renders <ProgressTrackerStepLabel /> with label or description', () => {
        const progressTracker = dom_1.mount(<ProgressTracker_1.ProgressTracker activeStep="step2">
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(1)} description="Description 1"/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(2)} description="Description 2"/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(3)}/>
      </ProgressTracker_1.ProgressTracker>);
        const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep,] = progressTracker.findAll(ProgressTrackerStep_1.ProgressTrackerStep);
        expect(firstProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepLabel, {
            label: 'Step 1',
            description: 'Description 1',
        });
        expect(secondProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepLabel, {
            label: 'Step 2',
            description: 'Description 2',
        });
        expect(finalProgressTrackerStep).toContainReactComponent(ProgressTrackerStep_1.ProgressTrackerStepLabel, {
            label: 'Step 3',
        });
        expect(firstProgressTrackerStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 1');
        expect(secondProgressTrackerStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 2');
        expect(finalProgressTrackerStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 3');
        expect(firstProgressTrackerStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(secondProgressTrackerStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(finalProgressTrackerStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 1);
    });
    it('renders a <li> with a aria-current attribute', () => {
        const progressTracker = dom_1.mount(<ProgressTracker_1.ProgressTracker activeStep="step2">
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(1)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(2)}/>
        <ProgressTrackerStep_1.ProgressTrackerStep {...defaultProps(3)}/>
      </ProgressTracker_1.ProgressTracker>);
        const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep,] = progressTracker.findAll(ProgressTrackerStep_1.ProgressTrackerStep);
        expect(firstProgressTrackerStep).toContainReactComponent('li', {
            'aria-current': false,
        });
        expect(secondProgressTrackerStep).toContainReactComponent('li', {
            'aria-current': true,
        });
        expect(finalProgressTrackerStep).toContainReactComponent('li', {
            'aria-current': false,
        });
    });
});
