"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFocusTrap = void 0;
const react_1 = require("react");
const FOCUSABLE_ELEMENTS = `
  a[href],
  area[href],
  input:not([type="hidden"]):not([disabled]):not([tabindex="-1"]),
  select:not([disabled]),
  textarea:not([disabled]),
  button:not([disabled]):not([tabindex="-1"]),
  iframe,
  object,
  embed,
  [tabindex="0"],
  [contenteditable],
  audio[controls],
  video[controls]`;
function useFocusTrap() {
    const ref = react_1.useRef(null);
    const findFocusableElements = react_1.useCallback((ref) => {
        var _a;
        const focusableElements = (_a = ref === null || ref === void 0 ? void 0 : ref.current) === null || _a === void 0 ? void 0 : _a.querySelectorAll(FOCUSABLE_ELEMENTS);
        if (focusableElements && focusableElements.length > 0) {
            const { 0: firstElement, [focusableElements.length - 1]: lastElement, } = focusableElements;
            return { firstElement, lastElement };
        }
        return { firstElement: null, lastElement: null };
    }, []);
    const setRef = react_1.useCallback((node) => {
        if (node) {
            if (!ref.current) {
                ref.current = node;
                setTimeout(() => {
                    var _a;
                    (_a = ref === null || ref === void 0 ? void 0 : ref.current) === null || _a === void 0 ? void 0 : _a.focus();
                });
            }
        }
        else {
            ref.current = null;
        }
    }, []);
    react_1.useEffect(() => {
        const handleKeyDown = (event) => {
            const { firstElement, lastElement } = findFocusableElements(ref);
            switch (event.key) {
                case 'Tab':
                    if (event.shiftKey) {
                        if (lastElement && document.activeElement === firstElement) {
                            event.preventDefault();
                            lastElement.focus();
                        }
                    }
                    else if (!event.shiftKey) {
                        if (firstElement && document.activeElement === lastElement) {
                            event.preventDefault();
                            firstElement.focus();
                        }
                    }
                    break;
            }
        };
        document.addEventListener('keydown', handleKeyDown);
        return () => {
            document.removeEventListener('keydown', handleKeyDown);
        };
    }, [findFocusableElements]);
    return setRef;
}
exports.useFocusTrap = useFocusTrap;
