"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utilities_1 = require("../test-utilities");
const focusTrap_1 = require("./focusTrap");
jest.useFakeTimers();
describe('useFocusTrap', () => {
    const rawCreateElement = document.createElement;
    const focusSpy = jest.fn();
    const createElementSpy = jest.spyOn(document, 'createElement');
    beforeEach(() => {
        createElementSpy.mockImplementation((...args) => {
            const result = rawCreateElement.apply(document, args);
            if (args[0].toLocaleLowerCase() === 'div') {
                result.focus = focusSpy;
            }
            return result;
        });
    });
    afterEach(() => {
        focusSpy.mockReset();
    });
    afterAll(() => {
        createElementSpy.mockRestore();
    });
    it('focuses the element attached to the reference', () => {
        function Component() {
            const ref = focusTrap_1.useFocusTrap();
            return <div ref={ref}>Hello</div>;
        }
        const component = test_utilities_1.mountWithContext(<Component />);
        component.act(() => {
            jest.runAllTimers();
        });
        expect(focusSpy).toHaveBeenCalled();
    });
});
